function IPT_tests = do_IPT_tests(OneStepPredictors, modelName, data, windowSize, ...
    distributions, estimationOutput)

returns = data.returns;
mu      = data.cond_m_ar1;

[T,N] = size(returns);
omegaStar = ones(N,1)/N; % portfolio with equal weights

if strcmp(modelName, 'TDCC') || strcmp(modelName(1:6), 'TGARCH')
    distributions = [distributions, 'endogenous'];
    updateIndexes = estimationOutput.updateIndexes;
end

for j = 1:length(distributions)
    IPT_tests.(distributions{j}).IPT = nan(T,1);
    if strcmpi(distributions{j},'normal')
        DoF.(distributions{j}) = inf;
    elseif strcmpi(distributions{j}(1),'t')
        DoF.(distributions{j}) = str2double(distributions{j}(2:end));
    end
end

figureTitle = modelName;
figureTitle(figureTitle=='_') = '-';
h = waitbar(0, figureTitle);
for t = windowSize+2:T
    if ~mod(t,100)
        waitbar((t-windowSize)/(T-windowSize), h);
        drawnow
    end
    % -----------------------------------------------------------------------------------------
    % we need to get the DoF parameter for the TDCC and the TGARCH model:
    if strcmp(modelName, 'TDCC') || strcmp(modelName(1:6), 'TGARCH')
        if strcmp(estimationOutput.estimateParameters,'yes') && ismember(t-1,updateIndexes)
            estimatedParameters = estimationOutput.estimatedParameters{find(updateIndexes == t-1)};
            endogenous_DoF = estimatedParameters(end);
            DoF.endogenous = endogenous_DoF;
        end
    end
    % -----------------------------------------------------------------------------------------
    mu_t = mu(t,:)';
    expectedReturn = mu_t'*omegaStar;
    if size(OneStepPredictors.covariance,2) == 1
        % univariate case:
        variance = OneStepPredictors.covariance(t);
    else
        % multivariate case
        Sigma_t = OneStepPredictors.covariance(:,:,t);
        if ~isreal(Sigma_t)
            error('Sigma is complex')
        end
        %     Sigma_t = diag(diag(Sigma_t));
        Sigma_t = Sigma_t;
        variance = omegaStar'*Sigma_t*omegaStar;
    end

    tReturn = returns(t,:)*omegaStar;
    for j = 1:length(distributions)
        if isinf(DoF.(distributions{j}))
            IPT_tests.(distributions{j}).IPT(t) = normcdf(tReturn, expectedReturn, sqrt(variance));
        else
            standardizedReturn = (tReturn-expectedReturn)/sqrt(variance)/sqrt((DoF.(distributions{j})-2)/DoF.(distributions{j}));
            IPT_tests.(distributions{j}).IPT(t) = tcdf(standardizedReturn, DoF.(distributions{j}));
        end
    end
end
close(h);

%% compute the critical values

nGrid = 1000;
grid = [0.01:0.01:3];
X = ones(nGrid,1)*grid;
Y = (1:nGrid)'*ones(size(grid));
KS_series = 2*(-1).^(Y-1).*exp(-2*Y.^2.*X.^2);
Ku_series = 2*(4*Y.^2.*X.^2-1).*exp(-2*Y.^2.*X.^2);
KS_CDF = 1-sum(KS_series);
Ku_CDF = 1-sum(Ku_series);

grid = [-inf, grid, inf];
KS_CDF = [0, KS_CDF, 1];
Ku_CDF = [0, Ku_CDF, 1];

for j = 1:length(distributions)
    x1 = IPT_tests.(distributions{j}).IPT(~isnan(IPT_tests.(distributions{j}).IPT));
    x2 = (0:length(x1)-1)'/(length(x1)-1);
    binEdges    =  [-inf ; sort([x1;x2]) ; inf];
    
    N = length(x1);

    binCounts1  =  histc (x1 , binEdges, 1);
    binCounts2  =  histc (x2 , binEdges, 1);

    sumCounts1  =  cumsum(binCounts1)./sum(binCounts1);
    sumCounts2  =  cumsum(binCounts2)./sum(binCounts2);

    sampleCDF1  =  sumCounts1(1:end-1);
    sampleCDF2  =  sumCounts2(1:end-1);

    deltaCDF1 = max(sampleCDF1 - sampleCDF2);
    deltaCDF2 = max(sampleCDF2 - sampleCDF1);

    KS = sqrt(N)*max(deltaCDF1, deltaCDF2);
    Ku = (sqrt(N)+0.155+0.24/sqrt(N))*(deltaCDF1 + deltaCDF2);

    KS_pVal = 1-interp1(grid, KS_CDF, KS);
    Ku_pVal = 1-interp1(grid, Ku_CDF, Ku);

    IPT_tests.(distributions{j}).KS_stat = KS;
    IPT_tests.(distributions{j}).Ku_stat = Ku;

    IPT_tests.(distributions{j}).KS_pVal = KS_pVal;
    IPT_tests.(distributions{j}).Ku_pVal = Ku_pVal;

end





