function IPT_tests = do_IPT_tests_averageModel(OneStepPredictors, SampleLikelihoods, strategy, data, windowSize, ...
    distributions)

returns = data.returns;
mu      = data.cond_m_ar1;
nAssets = size(mu,2);

modelNames = fieldnames(SampleLikelihoods);
nModels = length(modelNames);
if strcmp(strategy.nModels,'all')
    strategy.nModels = nModels;
end

[T,N] = size(returns);
omegaStar = ones(N,1)/N; % portfolio with equal weights

for j = 1:length(distributions)
    IPT_tests.(distributions{j}).IPT = nan(T,1);
    if strcmpi(distributions{j},'normal')
        DoF.(distributions{j}) = inf;
    elseif strcmpi(distributions{j}(1),'t')
        DoF.(distributions{j}) = str2double(distributions{j}(2:end));
    end
end

figureTitle = strategy.name;
figureTitle(figureTitle=='_') = '-';
h = waitbar(0, figureTitle);
for t = windowSize+2:T
    if ~mod(t,100)
        waitbar((t-windowSize)/(T-windowSize), h);
        drawnow
    end

    for j = 1:length(distributions)
        allCriteria = nan(nModels,1);
        for k = 1:nModels
            if strcmp(modelNames{k}(1:4),'TGAR') || strcmp(modelNames{k},'TDCC')
                allCriteria(k) = SampleLikelihoods.(modelNames{k}).endogenous.(strategy.criterion)(t);
            else
                allCriteria(k) = SampleLikelihoods.(modelNames{k}).(distributions{j}).(strategy.criterion)(t);
            end
        end
        [sortedCriteria, indexes] = sort(allCriteria,'descend');
        selectedModels = indexes(1:strategy.nModels);
        switch strategy.weighting
            case 'equal'
                weights = ones(strategy.nModels,1)/strategy.nModels;
            case {'AIC','BIC'}
                Delta = nan(strategy.nModels,1);
                for k = 1:strategy.nModels
                    Delta(k) = sortedCriteria(k)-sortedCriteria(1);
                end
                weights = exp(Delta)/sum(exp(Delta));
        end
        Sigma_t = nan(nAssets,nAssets,strategy.nModels);
        mu_t = nan(nAssets,strategy.nModels);
        for k = 1:strategy.nModels
            Sigma_t(:,:,k) = OneStepPredictors.(modelNames{selectedModels(k)}).covariance(:,:,t);
            mu_t(:,k) = mu(t,:);
        end

        tReturn = returns(t,:)*omegaStar;
        IPT_tests.(distributions{j}).IPT(t) = 0;
        for k = 1:strategy.nModels
            expectedReturn = omegaStar'*mu_t(:,k);
            variance = omegaStar'*Sigma_t(:,:,k)*omegaStar;
            if isinf(DoF.(distributions{j}))
                IPT_tests.(distributions{j}).IPT(t) = IPT_tests.(distributions{j}).IPT(t) + ...
                    normcdf(tReturn, expectedReturn, sqrt(variance)) * weights(k);
            else
                standardizedReturn = (tReturn-expectedReturn)/sqrt(variance)/sqrt((DoF.(distributions{j})-2)/DoF.(distributions{j}));
                IPT_tests.(distributions{j}).IPT(t) = IPT_tests.(distributions{j}).IPT(t) + ...
                    tcdf(standardizedReturn, DoF.(distributions{j})) * weights(k);
            end
        end
    end
end
close(h);

%% compute the critical values

nGrid = 1000;
grid = [0.01:0.01:3];
X = ones(nGrid,1)*grid;
Y = (1:nGrid)'*ones(size(grid));
KS_series = 2*(-1).^(Y-1).*exp(-2*Y.^2.*X.^2);
Ku_series = 2*(4*Y.^2.*X.^2-1).*exp(-2*Y.^2.*X.^2);
KS_CDF = 1-sum(KS_series);
Ku_CDF = 1-sum(Ku_series);

grid = [-inf, grid, inf];
KS_CDF = [0, KS_CDF, 1];
Ku_CDF = [0, Ku_CDF, 1];

for j = 1:length(distributions)
    x1 = IPT_tests.(distributions{j}).IPT(~isnan(IPT_tests.(distributions{j}).IPT));
    x2 = (0:length(x1)-1)'/(length(x1)-1);
    binEdges    =  [-inf ; sort([x1;x2]) ; inf];

    N = length(x1);

    binCounts1  =  histc (x1 , binEdges, 1);
    binCounts2  =  histc (x2 , binEdges, 1);

    sumCounts1  =  cumsum(binCounts1)./sum(binCounts1);
    sumCounts2  =  cumsum(binCounts2)./sum(binCounts2);

    sampleCDF1  =  sumCounts1(1:end-1);
    sampleCDF2  =  sumCounts2(1:end-1);

    deltaCDF1 = max(sampleCDF1 - sampleCDF2);
    deltaCDF2 = max(sampleCDF2 - sampleCDF1);

    KS = sqrt(N)*max(deltaCDF1, deltaCDF2);
    Ku = (sqrt(N)+0.155+0.24/sqrt(N))*(deltaCDF1 + deltaCDF2);

    KS_pVal = 1-interp1(grid, KS_CDF, KS);
    Ku_pVal = 1-interp1(grid, Ku_CDF, Ku);

    IPT_tests.(distributions{j}).KS_stat = KS;
    IPT_tests.(distributions{j}).Ku_stat = Ku;

    IPT_tests.(distributions{j}).KS_pVal = KS_pVal;
    IPT_tests.(distributions{j}).Ku_pVal = Ku_pVal;

end





