function activeRiskManagement = do_activeRiskManagementAverageModel(OneStepPredictors, SampleLikelihoods, ...
    strategy, data, windowSize, distributions, maximumDailyLoss, delta, alpha, EstimationOutput)

returns = data.returns;
mu      = data.cond_m_ar1;
nAssets = size(mu,2);

modelNames = fieldnames(SampleLikelihoods);
nModels = length(modelNames);
if strcmp(strategy.nModels,'all')
    strategy.nModels = nModels;
end

[T,N] = size(returns);

for j = 1:length(distributions)
    activeRiskManagement.(distributions{j}).portfolioWeights = nan(T,N);
    activeRiskManagement.(distributions{j}).VaRConstraintBinding = nan(T,1);
    activeRiskManagement.(distributions{j}).return = nan(T,1);
    activeRiskManagement.(distributions{j}).psi = nan(T,1);
end

figureTitle = strategy.name;
figureTitle(figureTitle=='_') = '-';
h = waitbar(0, figureTitle);
for t = windowSize+2:T
    if ~mod(t,100)
        waitbar((t-windowSize)/(T-windowSize), h);
        drawnow
    end

    for j = 1:length(distributions)
        allCriteria = nan(nModels,1);
        for k = 1:nModels
            allCriteria(k) = SampleLikelihoods.(modelNames{k}).(distributions{j}).(strategy.criterion)(t);
        end
        [sortedCriteria, indexes] = sort(allCriteria,'descend');
        selectedModels = indexes(1:strategy.nModels);
        switch strategy.weighting
            case 'equal'
                weights = ones(strategy.nModels,1)/strategy.nModels;
            case {'AIC','BIC'}
                Delta = nan(strategy.nModels,1);
                for k = 1:strategy.nModels
                    Delta(k) = sortedCriteria(k)-sortedCriteria(1);
                end
                weights = exp(Delta)/sum(exp(Delta));
        end
        Sigma_t = nan(nAssets,nAssets,strategy.nModels);
        mu_t = nan(nAssets,strategy.nModels);
        DoF = inf(strategy.nModels,1);
        for k = 1:strategy.nModels
            Sigma_t(:,:,k) = OneStepPredictors.(modelNames{selectedModels(k)}).covariance(:,:,t);
            mu_t(:,k) = mu(t,:);
            if ~strcmp(distributions{j},'normal')
                DoF(k) = 7; % this part may need to be revisited if we use the endogenous DoF for the TDCC
            end
        end

        [omegaStar, isBinding, VaR, exitFlag, utility, psi] = ...
            meanVariancePortfolio_average_Newton(Sigma_t, mu_t, alpha, DoF, maximumDailyLoss, ...
            delta, weights, 1);

%         [omegaStar2, isBinding2, VaR2, utility2, psi2] = meanVariancePortfolio_average(Sigma_t, mu_t, alpha, DoF, maximumDailyLoss, delta, weights);

%         if ~exitFlag
%             [omegaStar3, isBinding3, VaR3, exitFlag3, utility3, psi3] = ...
%                 meanVariancePortfolio_average_Newton(Sigma_t, mu_t, alpha, DoF, maximumDailyLoss, ...
%                 delta, weights, 1);
%         end

        if ~exitFlag
            disp('no convergence')
            keyboard
        end

        activeRiskManagement.(distributions{j}).portfolioWeights(t,:) = omegaStar';
        activeRiskManagement.(distributions{j}).VaRConstraintBinding(t) = isBinding;
        activeRiskManagement.(distributions{j}).return(t) = returns(t,:)*omegaStar;
        activeRiskManagement.(distributions{j}).psi(t) = psi;
    end
end
close(h);

for j = 1:length(distributions)
    activeRiskManagement.(distributions{j}).cumulativeReturn = nan(T,1);
    jReturn = activeRiskManagement.(distributions{j}).return;
    activeRiskManagement.(distributions{j}).cumulativeReturn(~isnan(jReturn)) = cumsum(jReturn(~isnan(jReturn)));
    activeRiskManagement.(distributions{j}).avReturn = nanmean(jReturn);
    activeRiskManagement.(distributions{j}).std = nanstd(jReturn);
    activeRiskManagement.(distributions{j}).IR = nanmean(jReturn) / nanstd(jReturn) * sqrt(250);
    activeRiskManagement.(distributions{j}).VaR.nViolations = sum(jReturn < - maximumDailyLoss);
    T1 = sum(~isnan(jReturn));
    activeRiskManagement.(distributions{j}).VaR.frequency = sum(jReturn < - maximumDailyLoss) / T1;
    pi = activeRiskManagement.(distributions{j}).VaR.frequency;
    activeRiskManagement.(distributions{j}).VaRConstraintBinding = ...
        nansum(activeRiskManagement.(distributions{j}).VaRConstraintBinding) / T1;
    activeRiskManagement.(distributions{j}).pi.stat = pi;
    activeRiskManagement.(distributions{j}).pi.pVal = 1-bino_cdf(T1*pi,T1,alpha);
    activeRiskManagement.(distributions{j}).T1 = T1;
    z = sqrt(T1)*(pi-alpha)/sqrt(alpha*(1-alpha));
    activeRiskManagement.(distributions{j}).z.stat = z;
    activeRiskManagement.(distributions{j}).z.pVal = 1-normcdf(z,0,1);
    activeRiskManagement.(distributions{j}).maximumSDailyLoss = maximumDailyLoss;
    activeRiskManagement.(distributions{j}).delta = delta;
    activeRiskManagement.(distributions{j}).alpha = alpha;
end

