function activeRiskManagement = do_activeRiskManagementSingleModel(OneStepPredictors, modelName, data, windowSize, distributions, ...
    maximumDailyLoss, delta, alpha, estimationOutput)

returns = data.returns;
mu      = data.cond_m_ar1;

[T,N] = size(returns);

if strcmp(modelName, 'TDCC')
    distributions = [distributions, 'endogenous'];
    updateIndexes = estimationOutput.updateIndexes;
end

for j = 1:length(distributions)
    activeRiskManagement.(distributions{j}).portfolioWeights = nan(T,N);
    activeRiskManagement.(distributions{j}).VaRConstraintBinding = nan(T,1);
    activeRiskManagement.(distributions{j}).return = nan(T,1);
    activeRiskManagement.(distributions{j}).return_1 = nan(T,1);
    activeRiskManagement.(distributions{j}).return_5 = nan(T,1);
    if strcmpi(distributions{j},'normal')
        cAlphaTilde.(distributions{j}) = norminv(alpha)*(-1);
    elseif strcmpi(distributions{j}(1),'t')
        DoF = str2double(distributions{j}(2:end));
        cAlpha = tinv(alpha,DoF)*(-1);
        cAlphaTilde.(distributions{j}) = sqrt((DoF-2)/DoF)*cAlpha;
    end
end

figureTitle = modelName;
figureTitle(figureTitle=='_') = '-';
h = waitbar(0, figureTitle);
for t = windowSize+2:T
    if ~mod(t,100)
        waitbar((t-windowSize)/(T-windowSize), h);
        drawnow
    end

    % -----------------------------------------------------------------------------------------
    % we need to get the DoF parameter for the TDCC model:
    if strcmp(modelName, 'TDCC')
        if strcmp(estimationOutput.estimateParameters,'yes') && ismember(t-1,updateIndexes)
            estimatedParameters = estimationOutput.estimatedParameters{find(updateIndexes == t-1)};
            endogenous_DoF = estimatedParameters(end);
            cAlpha = tinv(alpha,endogenous_DoF)*(-1);
            cAlphaTilde.endogenous = sqrt((endogenous_DoF-2)/endogenous_DoF)*cAlpha;
        end
    end
    % -----------------------------------------------------------------------------------------
    Sigma_t = OneStepPredictors.covariance(:,:,t);
    if ~isreal(Sigma_t)
        error('Sigma is complex')
    end
    %     Sigma_t = diag(diag(Sigma_t));
    mu_t = mu(t,:);

    indexes = (1:N);

    mu_t = mu_t(indexes);
    Sigma_t = Sigma_t(indexes,indexes);

    for j = 1:length(distributions)
        [omegaStar, isBinding] = meanVariancePortfolio_t(Sigma_t, mu_t, alpha, DoF, maximumDailyLoss, ...
            delta, cAlphaTilde.(distributions{j}));
        activeRiskManagement.(distributions{j}).portfolioWeights(t,indexes) = omegaStar';
        activeRiskManagement.(distributions{j}).VaRConstraintBinding(t) = isBinding;
        activeRiskManagement.(distributions{j}).return(t) = returns(t,indexes)*omegaStar;
    end
end
close(h);

for j = 1:length(distributions)
    activeRiskManagement.(distributions{j}).cumulativeReturn = nan(T,1);
    jReturn = activeRiskManagement.(distributions{j}).return;
    activeRiskManagement.(distributions{j}).cumulativeReturn(~isnan(jReturn)) = cumsum(jReturn(~isnan(jReturn)));
    activeRiskManagement.(distributions{j}).avReturn = nanmean(jReturn);
    activeRiskManagement.(distributions{j}).std = nanstd(jReturn);
    activeRiskManagement.(distributions{j}).IR = nanmean(jReturn) / nanstd(jReturn) * sqrt(250);
    activeRiskManagement.(distributions{j}).VaR.nViolations = sum(jReturn < - maximumDailyLoss);
    T1 = sum(~isnan(jReturn));
    activeRiskManagement.(distributions{j}).VaR.frequency = sum(jReturn < - maximumDailyLoss) / T1;
    pi = activeRiskManagement.(distributions{j}).VaR.frequency;
    activeRiskManagement.(distributions{j}).VaRConstraintBinding = ...
        nansum(activeRiskManagement.(distributions{j}).VaRConstraintBinding) / T1;
    activeRiskManagement.(distributions{j}).pi.stat = pi;
    activeRiskManagement.(distributions{j}).pi.pVal = 1-bino_cdf(T1*pi,T1,alpha);
    activeRiskManagement.(distributions{j}).T1 = T1;
    z = sqrt(T1)*(pi-alpha)/sqrt(alpha*(1-alpha));
    activeRiskManagement.(distributions{j}).z.stat = z;
    activeRiskManagement.(distributions{j}).z.pVal = 1-normcdf(z,0,1);
    activeRiskManagement.(distributions{j}).maximumSDailyLoss = maximumDailyLoss;
    activeRiskManagement.(distributions{j}).delta = delta;
    activeRiskManagement.(distributions{j}).alpha = alpha;
end

