function [sampleLikelihoods, predictors] = compute_likelihoodsAndPredictors(...
    estimationOutput, modelName, returns, windowSize, nu, distributions)

[T,N] = size(returns);
modelType = estimationOutput.type;
updateIndexes = estimationOutput.updateIndexes;

if strcmp(modelName, 'TDCC')
    distributions = [distributions, 'endogenous'];
end

predictors.covariance = nan(N,N,T);
for j = 1:length(distributions)
    sampleLikelihoods.(distributions{j}).likelihood = nan(T,1);
    sampleLikelihoods.(distributions{j}).BIC        = nan(T,1);
    sampleLikelihoods.(distributions{j}).AIC        = nan(T,1);
    predictors.likelihoods.(distributions{j})       = nan(T,1);
end

figureTitle = modelName;
figureTitle(figureTitle=='_') = '-';
h = waitbar(0, figureTitle);
estimatedParameters = [];
for t = windowSize+1:T
    if ~mod(t,100)
        %         disp(t)
        waitbar((t-windowSize)/(T-windowSize), h)
    end
    drawnow
    if strcmp(estimationOutput.estimateParameters,'yes') && ismember(t,updateIndexes)
        estimatedParameters = estimationOutput.estimatedParameters{find(updateIndexes == t)};
        if strcmp(modelName, 'TDCC')
            endogenous_DoF = estimatedParameters(end);
        end
        nParameters = get_nParameters(estimatedParameters, modelType);
    end
    if strcmp(estimationOutput.estimateParameters,'no')
        nParameters = 0;
    end
    Sigma = evaluate_volatilityModel(estimationOutput, returns(t-windowSize+1:t,:), estimatedParameters);
    determinant = nan(windowSize+1,1);
    x_InvSigma_x   = nan(windowSize+1,1);
    for j = 1:windowSize+1
        Sigma_j = Sigma(:,:,j);
        if ~sum(any(isnan(Sigma_j)))
            try
                determinant(j) = det(Sigma_j);
                x_InvSigma_x(j) = returns(t-windowSize+j,:)*inv(Sigma_j)*returns(t-windowSize+j,:)';
            catch
            end
        end
    end
    if t < T
        predictors.covariance(:,:,t+1) = Sigma(:,:,windowSize+1);
    end
    for j = 1:length(distributions)
        if strcmpi(distributions{j},'normal')
            distributionType = 'normal';
            dof = [];
        end
        if strcmpi(distributions{j}(1),'t')
            distributionType = 'student-t';
            if strcmpi(distributions{j},'tnu')
                dof = nu;
            else
                dof = str2num(distributions{j}(2:end));
            end
        elseif strcmpi(distributions{j},'endogenous')
            distributionType = 'student-t';
            dof = endogenous_DoF;
        end
        sampleLikelihoods.(distributions{j}).likelihood(t) = ...
            compute_likelihood(returns(t-windowSize+1:t,:),...
            determinant(1:windowSize),x_InvSigma_x(1:windowSize),distributionType,dof);
        sampleLikelihoods.(distributions{j}).BIC(t) = ...
            sampleLikelihoods.(distributions{j}).likelihood(t) - nParameters;
        sampleLikelihoods.(distributions{j}).AIC(t) = ...
            sampleLikelihoods.(distributions{j}).likelihood(t) - 0.5*nParameters*log(windowSize);
        if t < T
            predictors.likelihoods.(distributions{j})(t) = ...
                compute_likelihood(returns(t+1,:),...
                determinant(windowSize+1),x_InvSigma_x(windowSize+1),distributionType,dof);
        end
    end
end
close(h)


function logLikelihood = compute_likelihood(returns, determinant, x_invSigma_x, distribution, nu)

[T,N] = size(returns);

tLogLikelihoods = nan(T,1);
switch distribution
    case 'normal'
        tLogLikelihoods = -0.5*N*log(2*pi) - 0.5*log(determinant) - 0.5*x_invSigma_x;

    case 'student-t'
        tLogLikelihoods = log(gamma(0.5*(N+nu))/gamma(0.5*nu)) - 0.5*N*log(pi) - 0.5*N*log(nu-2) ...
            - 0.5*log(determinant) - 0.5*(N+nu)*log(1+x_invSigma_x/(nu-2));
end
nMissingObs = sum(isnan(tLogLikelihoods));
logLikelihood = nansum(tLogLikelihoods);
logLikelihood = logLikelihood * T / (T-nMissingObs);

