function [cond_m_ar1, ret_res] = generate_AR1_forecasts(returns, windowSize, data)

% generates the 1-step ahead mean forecasts cond_m_ar1 and the one-step
% ahead forecast errors ret_res from the input series using a rolling
% window of size windowSize

[T,N] = size(returns);

cond_m_ar1 = nan(T,N);
ARcoefficients = nan(T,N);

for iSeries = 1:N
    for t = windowSize+1:T-1
        Y = returns(t-windowSize+1:t,iSeries);
        X = [ones(windowSize,1), returns(t-windowSize:t-1,iSeries)];
        betaHat = inv(X'*X)*X'*Y;
        ARcoefficients(t,iSeries) = betaHat(2);
        if t == windowSize + 1
            cond_m_ar1(2:t,iSeries) = X*betaHat;
        end
        cond_m_ar1(t+1,iSeries) = [1, returns(t,iSeries)] * betaHat;    
    end
end

ret_res = returns - cond_m_ar1;

%% Print the AR coefficients (mean, median, min, max)
for iSeries = 1:N
    iString = data.variableNamesShort{iSeries};
    iString = [iString, blanks(15-length(iString))];
    iMean = num2str(nanmean(ARcoefficients(:,iSeries)),'%1.2f');
    iMedian = num2str(nanmedian(ARcoefficients(:,iSeries)),'%1.2f');
    iMin = num2str(nanmin(ARcoefficients(:,iSeries)),'%1.2f');
    iMax = num2str(nanmax(ARcoefficients(:,iSeries)),'%1.2f');
    iString = [iString, blanks(10-length(iMean)), iMean, ...
        blanks(10-length(iMedian)), iMedian, ...
        blanks(10-length(iMin)), iMin, ...
        blanks(10-length(iMax)), iMax];
    disp(iString)
end



% i=1;
% for i=1:15;
%     disp(i)
%     t=801;
%     for t=801:T-1;
%     results=ols(ret(t-799:t,i),[ones(800,1) ret(t-799-1:t-1,i)  ]);
%     cond_m_ar1(t+1,i)= results.beta(1) + results.beta(2)*ret(t,i);
%     ret_res(t+1,i)=ret(t+1,i) - cond_m_ar1(t+1,i);
% if t==801;
%     cond_m_ar1(2:t,i)=results.yhat;
%     ret_res(2:t,i)=results.resid;
% end;
% %         if ret(t+1,i) > 0;
% %         sa(t+1,i) = 1;
% %     end;
% %     if cond_m_ar5(t+1,i) > 0;
% %         sf_ar5(t+1,i) = 1;
% %     end;
% %     if cond_m_ar1(t+1,i) > 0;
% %         sf_ar1(t+1,i) = 1;
% %     end;
%     end;
% end;
