% clear, clc
currentDirectory = cd; cd .., baseDirectory = marm_globalSettings; cd(currentDirectory)
fontSize = 'scriptsize';

load([baseDirectory,'ActiveRiskManagement.mat'])
distributions = {'t7','normal'};

singleModels = fieldnames(ActiveRiskManagement.singleModel);
averageModels = fieldnames(ActiveRiskManagement.averageModel);
bestModels = {'best_AIC', 'best_BIC', 'Bayesian_AIC', 'Bayesian_BIC'};
averageModels = setdiff(averageModels, bestModels);


k = 1
for j = 1:length(singleModels)
    pi.single(j) = ActiveRiskManagement.singleModel.(singleModels{j}).(distributions{k}).pi.stat;
    IR.single(j) = ActiveRiskManagement.singleModel.(singleModels{j}).(distributions{k}).IR;
end

for j = 1:length(averageModels)
    pi.average(j) = ActiveRiskManagement.averageModel.(averageModels{j}).(distributions{k}).pi.stat;
    IR.average(j) = ActiveRiskManagement.averageModel.(averageModels{j}).(distributions{k}).IR;
end

for j = 1:length(bestModels)
    pi.best(j) = ActiveRiskManagement.averageModel.(bestModels{j}).(distributions{k}).pi.stat;
    IR.best(j) = ActiveRiskManagement.averageModel.(bestModels{j}).(distributions{k}).IR;
end

figure(1), set(gcf,'position',[337   336   891   612])
title(distributions{k})
scatter(pi.single, IR.single, 'bo')
hold on
scatter(pi.average, IR.average, 'rs', 'filled')
scatter(pi.best, IR.best, 'k^')
v = axis;
plot([0.01,0.01],[v(3),v(4)],':k')
hold off
xlabel('VaR exceedance (%)')
ylabel('IR')
print([baseDirectory,'tex\figures\scatter-plot.',distributions{k},'.eps'],'-deps');

%%
figure(2), set(gcf,'position',[337   336   891   612])
title(distributions{k})
scatter(pi.single, IR.single, 70, [0.75, 0.25, 0.75], 'o', 'filled')
hold on
scatter(pi.average, IR.average, 70, [0.25, 0.75, 0.25],  's', 'filled')
scatter(pi.best, IR.best, 70, [0.25, 0.5, 0.75], '^', 'filled')
v = axis;
plot([0.01,0.01],[v(3),v(4)],':k')
hold off
legend('individual models', 'thick model averaging', 'best and Bayesian averages')
xlabel('VaR exceedance (%)')
ylabel('IR')
print([baseDirectory,'tex\figures\scatter-plot.color.',distributions{k},'.eps'],'-depsc');

%%
figure(3), set(gcf,'position',[337   336   891   612])
title(distributions{k})
scatter(pi.single, IR.single, 70, [0.5, 0.75, 0.75], 'o', 'filled')
hold on
scatter(pi.average, IR.average, 70, 'rs', 'filled')
scatter(pi.best, IR.best, 70, 'b^', 'filled')
v = axis;
plot([0.01,0.01],[v(3),v(4)],':k')
hold off
legend('individual models', 'thick model averaging', 'best and Bayesian averages')
xlabel('VaR exceedance (%)')
ylabel('IR')
print([baseDirectory,'tex\figures\scatter-plot.color2.',distributions{k},'.eps'],'-depsc');




