% clear, clc
currentDirectory = cd; cd .., baseDirectory = marm_globalSettings; cd(currentDirectory)
fontSize = 'scriptsize';

addpath([baseDirectory, 'general'])
addpath(genpath([baseDirectory, 'volatility models\']))
load([baseDirectory,'data.mat'])

if 0
    UnivariateGARCHs = get_univariateGARCHs(data);
    save([baseDirectory,'UnivariateGARCHs.mat'],'UnivariateGARCHs')
else
    load([baseDirectory,'UnivariateGARCHs.mat'])
end

%% Summary Statistics
if 0
    marm_tables_summary_stats(baseDirectory,data,UnivariateGARCHs,fontSize)
end

%% Correlation Tables
if 0
    marm_tables_correlation(baseDirectory, data)
end

%% In-sample likelihoods, BICs, and AICs
if 1
    load([baseDirectory,'SampleLikelihoods.mat'])
    load([baseDirectory,'EstimationOutput.mat'])

    distributions = {'t7','normal'};
    likelihoodTypes = {'likelihood','BIC','AIC'};
    marm_tables_logLikelihood(baseDirectory,SampleLikelihoods,EstimationOutput,Models,data,distributions,likelihoodTypes,fontSize)
    marm_tables_logLikelihood_presentation(baseDirectory,SampleLikelihoods,EstimationOutput,Models,data,{'t7'},{'AIC'},fontSize)
end

%% In-sample likelihoods, BICs, and AICs for univariate models
if 1
    load([baseDirectory,'UnivariateOutput.mat'])

    distributions = {'t7','normal'};
    likelihoodTypes = {'likelihood','BIC','AIC'};
    marm_tables_univariateLogLikelihood(baseDirectory,UnivariateOutput,UnivariateModels,data,distributions,likelihoodTypes,fontSize)
    marm_tables_univariateLogLikelihood_presentation(baseDirectory,UnivariateOutput,UnivariateModels,data,{'t7'},{'AIC'},fontSize)
end

%% Active risk-management

%  Single models
if 0
    load([baseDirectory,'ActiveRiskManagement.mat'])
    distributions = {'t7','normal'};
    marm_tables_activeRiskManagement_single(baseDirectory,ActiveRiskManagement,distributions,fontSize)
    marm_tables_activeRiskManagement_single_presentation(baseDirectory,ActiveRiskManagement,distributions,fontSize)
%     marm_tables_activeRiskManagement_single(baseDirectory,ActiveRiskManagement,distributions,fontSize)
end

%  Average models
if 0
    load([baseDirectory,'ActiveRiskManagement.mat'])
    distributions = {'t7','normal'};
    marm_tables_activeRiskManagement_average(baseDirectory,ActiveRiskManagement,distributions,fontSize)
end


%% Passive risk-management

%  Single models
if 0
    load([baseDirectory,'PassiveRiskManagement.mat'])
    distributions = {'t7','normal'};
    alphas = {'1','5'};
    marm_tables_passiveRiskManagement_single(baseDirectory,PassiveRiskManagement,distributions,fontSize,alphas)
    marm_tables_passiveRiskManagement_single_presentation(baseDirectory,PassiveRiskManagement,distributions,fontSize,{'1'})
end

%  Average models
if 0
    load([baseDirectory,'ActiveRiskManagement.mat'])
    distributions = {'t7','normal'};
    marm_tables_passiveRiskManagement_average(baseDirectory,PassiveRiskManagement.averageModel,distributions,fontSize)
end

%  Single models (univariate)
if 0
    load([baseDirectory,'PassiveRiskManagement.mat'])
    distributions = {'t7','normal'};
    alphas = {'1','5'};
    marm_tables_passiveRiskManagement_singleUnivariate(baseDirectory,PassiveRiskManagement.univariate.singleModel,...
        distributions,fontSize,alphas)
    marm_tables_passiveRiskManagement_singleUnivariate_presentation(baseDirectory,PassiveRiskManagement.univariate.singleModel,...
        distributions,fontSize)
end

%  Average models (univariate)
if 0
    load([baseDirectory,'PassiveRiskManagement.mat'])
    distributions = {'t7','normal'};
    alphas = {'1','5'};
    marm_tables_passiveRiskManagement_averageUnivariate(baseDirectory,PassiveRiskManagement.univariate.averageModel,...
        distributions,fontSize,alphas)
end

%% Percentiles (how often model x is in top y percentile)

if 0
    load([baseDirectory,'Ranks.mat'])
    distributions = {'t7','normal'};
    marm_tables_ranks_multivariate(baseDirectory,Ranks.multivariate,distributions,fontSize)
    marm_tables_ranks_univariate(baseDirectory,Ranks.univariate,distributions,fontSize)
end

%% AIC and BIC weights

if 0
    load([baseDirectory,'Ranks.mat'])
    distributions = {'normal','t7'};
    marm_tables_weights(baseDirectory,BayesianWeights.multivariate,10,fontSize,'multivariate')
    marm_tables_weights(baseDirectory,BayesianWeights.univariate,10,fontSize,'univariate')
end


%% Kolmogorov-Smirnov and Kuiper tests

if 0
    load([baseDirectory,'IPT_tests.mat'])
    distributions = {'t7','normal'};
    marm_tables_IPT_multivariate_single(baseDirectory,IPT_tests.multivariate.singleModel,fontSize)
    marm_tables_IPT_univariate_single(baseDirectory,IPT_tests.univariate.singleModel,fontSize)
    marm_tables_IPT_average(baseDirectory,IPT_tests.multivariate.averageModel,'multivariate',fontSize)
    marm_tables_IPT_average(baseDirectory,IPT_tests.univariate.averageModel,'univariate',fontSize)
end