function marm_tables_IPT_average(baseDirectory,IPT_tests,type,fontSize)

strategyNames = fieldnames(IPT_tests);

strategyArray = {
    'best_AIC',         'Best (AIC)';
    'best_BIC',         'Best (BIC)';
    'Bayesian_AIC',     'Bayesian Average (AIC)';
    'Bayesian_BIC',     'Bayesian Average (BIC)';
    'thick_10perc_AIC', 'Top 10\\%% (AIC)';
    'thick_10perc_BIC', 'Top 10\\%% (BIC)';
    'thick_25perc_AIC', 'Top 25\\%% (AIC)';
    'thick_25perc_BIC', 'Top 25\\%% (BIC)';
    'thick_50perc_AIC', 'Top 50\\%% (AIC)';
    'thick_50perc_BIC', 'Top 50\\%% (BIC)';
    'thick_75perc_AIC', 'Top 75\\%% (AIC)';
    'thick_75perc_BIC', 'Top 75\\%% (BIC)';
    'thick_all',        'All'
    };

fileName = ['IPT-tests.', type, '.averageModels.tex'];
if strcmp(type,'multivariate')
    caption = ['Kuiper and Kolmogorov-Smirnov Tests of the Validity for the Multivariate Model Averaging Strategies Using an Equally Weighted Portfolio'];
elseif strcmp(type,'univariate')
    caption = ['Kuiper and Kolmogorov-Smirnov Tests of the Validity for the Univariate Model Averaging Strategies Using an Equally Weighted Portfolio'];
end

fid = fopen([baseDirectory,'\tex\tables\',fileName],'w');
fprintf(fid, '\\begin{table}[h!] \n');
fprintf(fid, '\\begin{%s} \n',fontSize);
fprintf(fid, ['\\caption{', caption, '} \n']);
fprintf(fid, ['\\label{T:', fileName(1:end-4), '} \n']);
fprintf(fid, '\\begin{center} \n');
fprintf(fid, '\\begin{tabular}{lrrrr} \n');
fprintf(fid, '\\\\ \n');
fprintf(fid, '\\hline \\hline \n');
fprintf(fid, ['Strategy type & \\multicolumn{2}{c}{normal} &  \\multicolumn{2}{c}{t7} \\\\ \n']);
fprintf(fid, [' & Ku & KS & Ku & KS \\\\ \n']);
fprintf(fid, '\\hline \n');

array = cell(length(strategyNames),5);

for j = 1:length(strategyNames)
    array{j,1} = strategyArray{j,2};
    
    array{j,2} = IPT_tests.(strategyNames{j}).normal.Ku_pVal;
    array{j,3} = IPT_tests.(strategyNames{j}).normal.KS_pVal;
    array{j,4} = IPT_tests.(strategyNames{j}).t7.Ku_pVal;
    array{j,5} = IPT_tests.(strategyNames{j}).t7.KS_pVal;
end
   
for j = 1:size(array,1)
    genericString = array{j,1};
    for k = 2:size(array,2)
            genericString = [genericString, ' & ', num2str(array{j,k},'%1.3f')]; %#ok<AGROW>
    end
    %             genericString = replace_underscores(genericString);

    fprintf(fid, [genericString, '\\\\ \n']);
end

fprintf(fid, '\\hline \\hline \n');
fprintf(fid, '\\end{tabular} \n');
fprintf(fid, '\\end{center} \n');
fprintf(fid, '\\end{%s} \n',fontSize);
fprintf(fid, '\\end{table} \n');
fclose(fid);







