function marm_tables_IPT_multivariate_single(baseDirectory,IPT_tests,fontSize)

parameterDescriptions.EQMA          = '($n_0$)';
parameterDescriptions.EWMA          = '($n_0,\\lambda_0,\\nu_0$)';
parameterDescriptions.MMA           = '($n_0,\\nu_0$)';
parameterDescriptions.GEWMA         = '($p,q,\\nu_0$)';
parameterDescriptions.DCC           = '($p,q$)';
parameterDescriptions.ADCC          = '($p,q$)';
parameterDescriptions.CCC           = '($p,q$)';
parameterDescriptions.OGARCH        = '($p,q$)';
parameterDescriptions.factorGARCH   = '($p,q$)';
parameterDescriptions.factorGARCH   = '($p,q$)';
parameterDescriptions.TDCC          = '($p,q$)';

Models = listOfModels;

modelTypes = {'EQMA','EWMA','MMA','GEWMA','OGARCH','CCC','DCC','ADCC','TDCC'};

modelNames = fieldnames(Models);

fileName = ['IPT-tests.multivariate.singleModels.tex'];
caption = ['Kuiper and Kolmogorov-Smirnov Tests of the Validity of the Individual Multivariate Models Using an Equally Weighted Portfolio'];

fid = fopen([baseDirectory,'\tex\tables\',fileName],'w');
fprintf(fid, '\\begin{table}[h!] \n');
fprintf(fid, '\\begin{%s} \n',fontSize);
fprintf(fid, ['\\caption{', caption, '} \n']);
fprintf(fid, ['\\label{T:', fileName(1:end-4), '} \n']);
fprintf(fid, '\\begin{center} \n');
fprintf(fid, '\\begin{tabular}{lrrrr|lrrrr} \n');
fprintf(fid, '\\\\ \n');
fprintf(fid, '\\hline \\hline \n');
fprintf(fid, ['Model type & \\multicolumn{2}{c}{normal} &  \\multicolumn{2}{c}{t7} & ', ...
    ' Model type & \\multicolumn{2}{c}{normal} & \\multicolumn{2}{c}{t7} \\\\ \n']);
fprintf(fid, ['& Ku & KS & Ku & \\multicolumn{1}{r}{KS} & & Ku & KS & Ku & KS \\\\ \n']);
fprintf(fid, '\\hline \n');

array = cell(length(modelNames),5);

for j = 1:length(modelNames)
    array{j,1} = modelNames{j};
    array{j,2} = IPT_tests.(modelNames{j}).normal.Ku_pVal;
    array{j,3} = IPT_tests.(modelNames{j}).normal.KS_pVal;
    if strcmp(modelNames{j},'TDCC')
        array{j,4} = IPT_tests.(modelNames{j}).endogenous.Ku_pVal;
        array{j,5} = IPT_tests.(modelNames{j}).endogenous.KS_pVal;
    else
        array{j,4} = IPT_tests.(modelNames{j}).t7.Ku_pVal;
        array{j,5} = IPT_tests.(modelNames{j}).t7.KS_pVal;
    end
end

outputArray = cell(40,10);
rowCounter = 2;
columnCounter = 0;
for j = 1:length(modelTypes)
    %             if strcmp(modelTypes{j},'OGARCH')
    %                 rowCounter = 2;
    %                 columnCounter = 7;
    %             end
    if strcmp(modelTypes{j},'factorGARCH')
        outputArray{rowCounter,columnCounter+1} = 'factor GARCH';
    else
        outputArray{rowCounter,columnCounter+1} = modelTypes{j};
    end

    rowCounter = rowCounter + 1;
    outputArray{rowCounter,columnCounter+1} = parameterDescriptions.(modelTypes{j});
    rowCounter = rowCounter + 1;
    for k = 1:length(modelNames)
        if strcmp(Models.(modelNames{k}).type,modelTypes{j})
            if strcmp(modelNames{k},'GEWMA_250_1_1_97')
                rowCounter = 2;
                columnCounter = 5;
            end
            if iscell(Models.(modelNames{k}).fixedParameters)
                modelParameters = Models.(modelNames{k}).fixedParameters{1};
            else
                modelParameters = Models.(modelNames{k}).fixedParameters;
            end
            if  strcmp(modelTypes{j},'GEWMA')  % || strcmp(modelTypes{j},'EWMA')
                modelParameters = modelParameters(2:end);
            elseif strcmp(modelTypes{j},'TDCC')
                modelParameters = modelParameters(2:3);
            end

            modelParametersString = num2str(modelParameters(1));
            for l = 2:length(modelParameters)
                modelParametersString = [modelParametersString,',',num2str(modelParameters(l))]; %#ok<AGROW>
            end
            outputArray{rowCounter,columnCounter+1} = ['(',modelParametersString,')'];
            loc = strmatch(modelNames{k},array(:,1));
            outputArray{rowCounter,columnCounter+2} = num2str(array{loc,2},'%5.3f');
            outputArray{rowCounter,columnCounter+3} = num2str(array{loc,3},'%5.3f');
            outputArray{rowCounter,columnCounter+4} = num2str(array{loc,4},'%5.3f');
            outputArray{rowCounter,columnCounter+5} = num2str(array{loc,5},'%5.3f');

            rowCounter = rowCounter + 1;
        end
    end
    rowCounter = rowCounter + 1;
end

for j = 1:size(outputArray,1)
    genericString = outputArray{j,1};
    for k = 2:size(outputArray,2)
        if strcmp(outputArray{j,k},'factor GARCH')
            genericString = [genericString, ' & \\multicolumn{2}{l}{', outputArray{j,k}]; %#ok<AGROW>
        elseif strcmp(outputArray{j,k-1},'factor GARCH')
            genericString = [genericString, '} ']; %#ok<AGROW>
        else
            genericString = [genericString, ' & ', outputArray{j,k}]; %#ok<AGROW>
        end
    end
    %             genericString = replace_underscores(genericString);

    fprintf(fid, [genericString, '\\\\ \n']);
end

fprintf(fid, '\\hline \\hline \n');
fprintf(fid, '\\end{tabular} \n');
fprintf(fid, '\\end{center} \n');
fprintf(fid, '\\end{%s} \n',fontSize);
fprintf(fid, '\\end{table} \n');
fclose(fid);






