function marm_tables_activeRiskManagement_single(baseDirectory,ActiveRiskManagement,distributions,fontSize)

modelTypes = {'EQMA','EWMA','MMA','GEWMA','OGARCH','CCC','DCC','ADCC','TDCC'};

modelNames = fieldnames(ActiveRiskManagement.singleModel);
Models = listOfModels;

parameterDescriptions.EQMA          = '($n_0$)';
parameterDescriptions.EWMA          = '($n_0,\\lambda_0,\\nu_0$)';
parameterDescriptions.MMA           = '($n_0,\\nu_0$)';
parameterDescriptions.GEWMA         = '($p,q,\\nu_0$)';
parameterDescriptions.DCC           = '($p,q$)';
parameterDescriptions.ADCC          = '($p,q$)';
parameterDescriptions.CCC           = '($p,q$)';
parameterDescriptions.OGARCH        = '($p,q$)';
parameterDescriptions.factorGARCH   = '($p,q$)';
parameterDescriptions.factorGARCH   = '($p,q$)';
parameterDescriptions.TDCC          = '($p,q$)';


outputArray = cell(length(modelNames)+2*length(modelTypes),12);
rowCounter = 1;
for j = 1:length(modelTypes)
    %     rowCounter = rowCounter + 1;
    outputArray{rowCounter,1} = modelTypes{j};
    if strcmp(modelTypes{j},'OGARCH')
        partition = rowCounter;
    end
    %     rowCounter = rowCounter + 1;
    outputArray{rowCounter,2} = parameterDescriptions.(modelTypes{j});
    rowCounter = rowCounter + 1;
    for k = 1:length(modelNames)
        if strcmp(Models.(modelNames{k}).type,modelTypes{j})
            if iscell(Models.(modelNames{k}).fixedParameters)
                modelParameters = Models.(modelNames{k}).fixedParameters{1};
            else
                modelParameters = Models.(modelNames{k}).fixedParameters;
            end
            if  strcmp(modelTypes{j},'GEWMA')
                modelParameters = modelParameters(2:end);
            elseif strcmp(modelTypes{j},'TDCC')
                modelParameters = modelParameters(2:3);
            end
            modelParametersString = num2str(modelParameters(1));
            for l = 2:length(modelParameters)
                modelParametersString = [modelParametersString,',',num2str(modelParameters(l))]; %#ok<AGROW>
            end
            outputArray{rowCounter,2} = ['(',modelParametersString,')'];

            if ~strcmp(modelTypes{j},'TDCC')
            outputArray{rowCounter,3} = num2str(ActiveRiskManagement.singleModel.(modelNames{k}).normal.avReturn*100*250,'%1.2f');
            outputArray{rowCounter,4} = num2str(ActiveRiskManagement.singleModel.(modelNames{k}).normal.IR,'%1.2f');
            outputArray{rowCounter,5} = num2str(ActiveRiskManagement.singleModel.(modelNames{k}).normal.pi.stat*100 ,'%1.2f');
            outputArray{rowCounter,6} = num2str(ActiveRiskManagement.singleModel.(modelNames{k}).normal.z.stat ,'%1.2f');
            outputArray{rowCounter,7} = num2str(ActiveRiskManagement.singleModel.(modelNames{k}).normal.VaRConstraintBinding*100,'%1.0f');
            else
                outputArray{rowCounter,3} = '-';
                outputArray{rowCounter,4} = '-';
                outputArray{rowCounter,5} = '-';
                outputArray{rowCounter,6} = '-';
                outputArray{rowCounter,7} = '-';
            end
            
            if ~strcmp(modelTypes{j},'TDCC')
                distributionType = 't7';
            else
                distributionType = 'endogenous';
            end
            outputArray{rowCounter,8} = num2str(ActiveRiskManagement.singleModel.(modelNames{k}).(distributionType).avReturn*100*250,'%1.2f');
            outputArray{rowCounter,9} = num2str(ActiveRiskManagement.singleModel.(modelNames{k}).(distributionType).IR,'%1.2f');
            outputArray{rowCounter,10} = num2str(ActiveRiskManagement.singleModel.(modelNames{k}).(distributionType).pi.stat*100 ,'%1.2f');
            outputArray{rowCounter,11} = num2str(ActiveRiskManagement.singleModel.(modelNames{k}).(distributionType).z.stat ,'%1.2f');
            outputArray{rowCounter,12} = num2str(ActiveRiskManagement.singleModel.(modelNames{k}).(distributionType).VaRConstraintBinding*100,'%1.0f');

            rowCounter = rowCounter + 1;
        end
    end
    if j ~= length(modelTypes)
        %         outputArray{rowCounter,1} = 'line';
        rowCounter = rowCounter + 1;
    end
end

outputArray_1 = outputArray(1:partition-2,:);
outputArray_2 = outputArray(partition:end-1,:);


for jTable = 1:2;

    fileName = ['activeRiskManagement.singleModels.table-',num2str(jTable),'.tex'];
    caption = ['Information Ratios and VaR Diagnostic Tests for Optimal Portfolio (Individual Multivariate Models)'];
    %     if jTable == 2
    %         caption = [caption, ' (cont''d)'];
    %     end

    fid = fopen([baseDirectory,'\tex\tables\',fileName],'w');
    fprintf(fid, '\\begin{table}[h!] \n');
    fprintf(fid, '\\begin{%s} \n',fontSize);
    fprintf(fid, ['\\caption{', caption, '} \n']);
    fprintf(fid, ['\\label{T:', fileName(1:end-4), '} \n']);
    fprintf(fid, '\\begin{center} \n');
    fprintf(fid, '\\begin{tabular}{llrrrrr|rrrrr} \n');
    fprintf(fid, '\\\\ \n');
    fprintf(fid, '\\hline \\hline \n');
    fprintf(fid, ['Model type & & \\multicolumn{5}{c}{Normal} &  \\multicolumn{5}{c}{Student (7)}  \\\\ \n']);
    fprintf(fid, ' & & \\multicolumn{1}{r}{mean} &  IR & $\\hat{\\pi}$ & $z_{\\hat{\\pi}}$ & \\multicolumn{1}{r}{\\%% VaR} & mean & IR & $\\hat{\\pi}$ & $z_{\\hat{\\pi}}$  & \\%% VaR \\\\ \n');
    fprintf(fid, ' & & \\multicolumn{1}{r}{return}   &     &               &  \\multicolumn{2}{r}{ binds}    &  return &      &               &    &  binds \\\\ \n');
    fprintf(fid, '\\hline \n');

    if jTable == 1
        outputArray = outputArray_1;
    else
        outputArray = outputArray_2;
    end

    for j = 1:size(outputArray,1)
        if strcmp(outputArray{j,1},'line')
            fprintf(fid, '\\hline \n');
        else
            genericString = outputArray{j,1};
            for k = 2:size(outputArray,2)
                genericString = [genericString, ' & ', outputArray{j,k}]; %#ok<AGROW>
            end
            %             genericString = replace_underscores(genericString);
            fprintf(fid, [genericString, '\\\\ \n']);
        end
    end


    fprintf(fid, '\\hline \\hline \n');
    fprintf(fid, '\\end{tabular} \n');
    fprintf(fid, '\\end{center} \n');
    fprintf(fid, 'Nominal tolerance probability $\\alpha = 1\\%%$ \n');
    fprintf(fid, '\\end{%s} \n',fontSize);
    fprintf(fid, '\\end{table} \n');
    fclose(fid);
end