function marm_tables_correlation(baseDirectory, data)

if ~exist('data','var'), load([baseDirectory,'data.mat']), end

[T,N] = size(data.returns);

assets.currencies = {'GBP','EUR','JPY','CAD','AUD','CHF'};
assets.equities = {'SP','FTSE','DAX','NIKKEI'};
assets.bonds = {'10Y US','10Y EUR','10Y Gilt','10Y JGB'};
assets.commodities = {'Gold','Silver','Wheat','Crude'};

assetClasses = fieldnames(assets);
correlations = nan(N,length(assetClasses));

nAsset = 0;
assetNames = cell(N,1);
for j = 1:length(assetClasses)
    jAssets = assets.(assetClasses{j});
    for k = 1:length(jAssets)
        nAsset = nAsset+1;
        kAsset = jAssets{k};
        assetNames{nAsset} = kAsset;
        kReturn = data.returns(:,strmatch(kAsset,data.variableNamesShort));
        for l = 1:length(assetClasses)
            lCorrelations = [];
            lAssets = assets.(assetClasses{l});
            for m = 1:length(lAssets)
                mAsset = lAssets{m};
                if ~strcmp(lAssets{m},kAsset)
                    mReturn = data.returns(:,strmatch(mAsset,data.variableNamesShort));
                    lCorrelations = [lCorrelations; corr(kReturn,mReturn)];
                end
            end
            correlations(nAsset,l) = mean(lCorrelations);
        end
    end
end

tableName = 'correlations';
caption = 'Average Pairwise Correlations of Returns Within and Across Asset Classes';

fid = fopen([baseDirectory,'\tex\tables\',tableName,'.tex'],'w');
fprintf(fid, '\\begin{table}[h!] \n');
fprintf(fid, '\\scriptsize \n');
fprintf(fid, ['\\caption{', caption, '} \n']);
fprintf(fid, '\\label{T:correlations} \n');
fprintf(fid, '\\begin{center} \n');
fprintf(fid, '\\begin{tabular}{lrrrr} \n');
fprintf(fid, '\\\\ \n');
fprintf(fid, '\\hline \\hline \n');
fprintf(fid, 'Asset & Foreign Exchange   & Equity Indices & 10Y Bonds & commodities  \\\\ \n');
fprintf(fid, '\\hline \n');
for j = 1:length(assetClasses)
    jAssets = assets.(assetClasses{j});
    for k = 1:length(jAssets)
        kAsset = jAssets{k};
        loc = strmatch(kAsset,assetNames);
        fprintf(fid, [assetNames{loc}, ...
            '  & %1.3f & %1.3f & %1.3f & %1.3f \\\\ \n'], correlations(loc,:));
    end
    if j ~= length(assetClasses)
        fprintf(fid, '\\hline \n');
    end
end
fprintf(fid, '\\hline \\hline \n');

%%
fprintf(fid, '\\end{tabular} \n');
fprintf(fid, '\\end{center} \n');
fprintf(fid, '\\end{table} \n');

fclose(fid);