function marm_tables_logLikelihood_presentation(baseDirectory,SampleLikelihoods,EstimationOutput,Models,data,distributions,likelihoodTypes,fontSize)

% distributions = {'t8'};
% likelihoodTypes = {'likelihood','BIC','AIC'};
% likelihoodTypes = {'BIC'};

parameterDescriptions.EQMA          = '($n_0$)';
parameterDescriptions.EWMA          = '($n_0,\\lambda_0,\\nu_0$)';
parameterDescriptions.MMA           = '($n_0,\\nu_0$)';
parameterDescriptions.GEWMA         = '($p,q,\\nu_0$)';
parameterDescriptions.DCC           = '($p,q$)';
parameterDescriptions.ADCC          = '($p,q$)';
parameterDescriptions.CCC           = '($p,q$)';
parameterDescriptions.OGARCH        = '($p,q$)';
parameterDescriptions.factorGARCH   = '($p,q$)';
parameterDescriptions.factorGARCH   = '($p,q$)';
parameterDescriptions.TDCC          = '($p,q$)';

Models = listOfModels;

modelTypes = {'EQMA','EWMA','MMA','GEWMA','OGARCH','CCC','DCC','ADCC','TDCC'};

modelNames = fieldnames(Models);

groups{1} = {'EQMA','EWMA'};
groups{2} = {'MMA','GEWMA','OGARCH'};
groups{3} = {'CCC','DCC','ADCC','TDCC'};

for hGroup = 1:length(groups)
    for iDistribution = 1:length(distributions)
        for jLikelihoodType = 1:length(likelihoodTypes)

            fileName = ['sampleLogLikelihood.',distributions{iDistribution},'.',likelihoodTypes{jLikelihoodType},'.presentation.',num2str(hGroup),'.tex'];

            if strcmp(distributions{iDistribution},'normal')
                titleInnovations = ' Standard Normal';
            else
                dof = num2str(distributions{iDistribution}(2:end));
                titleInnovations = ' Student $t$';
            end

            if strcmp(likelihoodTypes{jLikelihoodType},'likelihood')
                caption = ['Maximized Log-Likelihood Values for Multivariate Volatility Models under ', titleInnovations , ' Innovations'];
            elseif strcmp(likelihoodTypes{jLikelihoodType},'AIC')
                caption = ['AIC Values for Multivariate Volatility Models under ', titleInnovations , ' Innovations'];
            elseif strcmp(likelihoodTypes{jLikelihoodType},'BIC')
                caption = ['SBC Values for Multivariate Volatility Models under ', titleInnovations , ' Innovations'];
            end

            firstDate = datestr(data.dates(801),'dd-mmm-yy');
            lastDate  = datestr(data.dates(end),'dd-mmm-yy');

            fid = fopen([baseDirectory,'\tex\tables\',fileName],'w');
            %         fprintf(fid, '\\begin{table}[h!] \n');
            fprintf(fid, '\\begin{%s} \n',fontSize);
            %         fprintf(fid, ['\\caption{', caption, '} \n']);
            %         fprintf(fid, ['\\label{T:', fileName(1:end-4), '} \n']);
            fprintf(fid, '\\begin{center} \n');
            fprintf(fid, '\\begin{tabular}{lrrrrrr} \n');
            fprintf(fid, '\\\\ \n');
            fprintf(fid, '\\hline \\hline \n');
            fprintf(fid, 'Model type & \\multicolumn{6}{c}{Sample periods}  \\\\ \n');
            fprintf(fid, [' & \\multicolumn{2}{c}{', firstDate, '} &  \\multicolumn{2}{c}{', lastDate, '} & \\multicolumn{2}{c}{Average}  \\\\ \n']);
            fprintf(fid, [' & \\multicolumn{2}{c}{(1)} &  \\multicolumn{2}{c}{(2)} & \\multicolumn{2}{c}{(3)}  \\\\ \n']);
            fprintf(fid, '\\hline \n');

            array = cell(length(modelNames),5);

            for j = 1:length(modelNames)
                if strcmp(modelNames{j},'TDCC')
                    genericDistribution = 'endogenous';
                else
                    genericDistribution = distributions{iDistribution};
                end

                array{j,1} = j;
                array{j,2} = modelNames{j};
                statistic.start = SampleLikelihoods.(modelNames{j}).(genericDistribution).likelihood(801);
                statistic.end = SampleLikelihoods.(modelNames{j}).(genericDistribution).likelihood(end);
                statistic.mean = nanmean(SampleLikelihoods.(modelNames{j}).(genericDistribution).likelihood);
                if strcmp(EstimationOutput.(modelNames{j}).estimateParameters,'no')
                    nParameters = 0;
                else
                    nParameters = get_nParameters(EstimationOutput.(modelNames{j}).estimatedParameters{1}, ...
                        EstimationOutput.(modelNames{j}).type);
                end
                switch likelihoodTypes{jLikelihoodType}
                    case 'AIC'
                        statistic.start = statistic.start - nParameters;
                        statistic.end   = statistic.end - nParameters;
                        statistic.mean  = statistic.mean - nParameters;
                    case 'BIC'
                        statistic.start = statistic.start - 0.5*nParameters*log(800);
                        statistic.end   = statistic.end - 0.5*nParameters*log(800);
                        statistic.mean  = statistic.mean - 0.5*nParameters*log(800);
                end

                array{j,3} = statistic.start;
                array{j,4} = statistic.end;
                array{j,5} = statistic.mean;
            end

            %
            % compute the ranks
            %

            rankStart = cell(length(modelNames),1);
            rankEnd   = cell(length(modelNames),1);
            rankMean  = cell(length(modelNames),1);

            startSample = cell2mat(array(:,3));
            [Y, I] = sort(real(startSample),'descend');
            for j = 1:length(modelNames)
                rankStart{I(j)} = j;
            end

            endSample = cell2mat(array(:,4));
            [Y, I] = sort(real(endSample),'descend');
            for j = 1:length(modelNames)
                rankEnd{I(j)} = j;
            end

            meanSample = cell2mat(array(:,5));
            [Y, I] = sort(real(meanSample),'descend');
            for j = 1:length(modelNames)
                rankMean{I(j)} = j;
            end

            outputArray = cell(2,7);
            rowCounter = 1;
            columnCounter = 0;
            for j = 1:length(modelTypes)
                %             if strcmp(modelTypes{j},'OGARCH')
                %                 rowCounter = 2;
                %                 columnCounter = 7;
                %             end
                if ismember(modelTypes{j},groups{hGroup})

                    outputArray{rowCounter,columnCounter+1} = modelTypes{j};
                    rowCounter = rowCounter + 1;
                    outputArray{rowCounter,columnCounter+1} = parameterDescriptions.(modelTypes{j});
                    rowCounter = rowCounter + 1;
                    for k = 1:length(modelNames)
                        if strcmp(Models.(modelNames{k}).type,modelTypes{j})
                            if iscell(Models.(modelNames{k}).fixedParameters)
                                modelParameters = Models.(modelNames{k}).fixedParameters{1};
                            else
                                modelParameters = Models.(modelNames{k}).fixedParameters;
                            end
                            if  strcmp(modelTypes{j},'GEWMA')  % || strcmp(modelTypes{j},'EWMA')
                                modelParameters = modelParameters(2:end);
                            elseif strcmp(modelTypes{j},'TDCC')
                                modelParameters = modelParameters(2:3);
                            end

                            modelParametersString = num2str(modelParameters(1));
                            for l = 2:length(modelParameters)
                                modelParametersString = [modelParametersString,',',num2str(modelParameters(l))]; %#ok<AGROW>
                            end
                            outputArray{rowCounter,columnCounter+1} = ['(',modelParametersString,')'];
                            loc = strmatch(modelNames{k},array(:,2));
                            outputArray{rowCounter,columnCounter+2} = num2str(array{loc,3},'%5.0f');
                            outputArray{rowCounter,columnCounter+4} = num2str(array{loc,4},'%5.0f');
                            outputArray{rowCounter,columnCounter+6} = num2str(array{loc,5},'%5.0f');
                            if strcmp(likelihoodTypes{jLikelihoodType},'AIC') || strcmp(likelihoodTypes{jLikelihoodType},'BIC')
                                outputArray{rowCounter,columnCounter+3} = ['(',num2str(rankStart{k},'%5.0f'),')'];
                                outputArray{rowCounter,columnCounter+5} = ['(',num2str(rankEnd{k},'%5.0f'),')'];
                                outputArray{rowCounter,columnCounter+7} = ['(',num2str(rankMean{k},'%5.0f'),')'];
                            end

                            %outputArray{rowCounter,columnCounter+5} = ['(',num2str(array{loc,6},'%5.0f'),')'];
                            rowCounter = rowCounter + 1;
                        end
                    end
                    rowCounter = rowCounter + 1;
                end

            end

            for j = 1:size(outputArray,1)
                genericString = outputArray{j,1};
                for k = 2:size(outputArray,2)
                    if strcmp(outputArray{j,k},'factor GARCH')
                        genericString = [genericString, ' & \\multicolumn{2}{l}{', outputArray{j,k}]; %#ok<AGROW>
                    elseif strcmp(outputArray{j,k-1},'factor GARCH')
                        genericString = [genericString, '} ']; %#ok<AGROW>
                    else
                        genericString = [genericString, ' & ', outputArray{j,k}]; %#ok<AGROW>
                    end
                end
                %             genericString = replace_underscores(genericString);

                fprintf(fid, [genericString, '\\\\ \n']);
            end

            fprintf(fid, '\\hline \\hline \n');
            fprintf(fid, '\\end{tabular} \n');
            fprintf(fid, '\\end{center} \n');
            fprintf(fid, '\\end{%s} \n',fontSize);
            %         fprintf(fid, '\\end{table} \n');
            fclose(fid);

        end
    end
end






