function marm_tables_passiveRiskManagement_average(baseDirectory,PassiveRiskManagement,distributions,fontSize,alphas)

strategyNames = fieldnames(PassiveRiskManagement);

strategyArray = {
    'best_AIC',         'Best (AIC)';
    'best_BIC',         'Best (BIC)';
    'Bayesian_AIC',     'Bayesian Average (AIC)';
    'Bayesian_BIC',     'Bayesian Average (BIC)';
    'thick_10perc_AIC', 'Top 10\\%% (AIC)';
    'thick_10perc_BIC', 'Top 10\\%% (BIC)';
    'thick_25perc_AIC', 'Top 25\\%% (AIC)';
    'thick_25perc_BIC', 'Top 25\\%% (BIC)';
    'thick_50perc_AIC', 'Top 50\\%% (AIC)';
    'thick_50perc_BIC', 'Top 50\\%% (BIC)';
    'thick_75perc_AIC', 'Top 75\\%% (AIC)';
    'thick_75perc_BIC', 'Top 75\\%% (BIC)';
    'thick_all',        'All'
    };

fileName = ['passiveRiskManagement.averageModels.tex'];
caption = 'VaR Diagnostic Tests for Equally Weighted Portfolio Return Using Multivariate Average Modelling Strategies';

fid = fopen([baseDirectory,'\tex\tables\',fileName],'w');
fprintf(fid, '\\begin{table}[h!] \n');
fprintf(fid, '\\begin{%s} \n',fontSize);
fprintf(fid, ['\\caption{', caption, '} \n']);
fprintf(fid, ['\\label{T:', fileName(1:end-4), '} \n']);
fprintf(fid, '\\begin{center} \n');
fprintf(fid, '\\begin{tabular}{lrrrr|rrrr} \n');
fprintf(fid, '\\\\ \n');
fprintf(fid, '\\hline \\hline \n');
fprintf(fid, ' & \\multicolumn{4}{c}{$\\alpha = 1\\%%$} & \\multicolumn{4}{c}{$\\alpha = 5\\%%$} \\\\ \n');
fprintf(fid, ['Strategy type & \\multicolumn{2}{c}{normal} &  \\multicolumn{2}{c}{t7} & ', ...
    ' \\multicolumn{2}{c}{normal} & \\multicolumn{2}{c}{t7} \\\\ \n']);
fprintf(fid, ['& $\\hat{\\pi}$ & $z_{\\hat{\\pi}}$ & $\\hat{\\pi}$ & \\multicolumn{1}{r}{$z_{\\hat{\\pi}}$} & ', ...
    ' $\\hat{\\pi}$ & $z_{\\hat{\\pi}}$ & $\\hat{\\pi}$ & $z_{\\hat{\\pi}}$ \\\\ \n']);
fprintf(fid, '\\hline \n');

array = cell(length(strategyNames),9);

for j = 1:length(strategyNames)
    array{j,1} = strategyArray{j,2};
    
    array{j,2} = num2str(PassiveRiskManagement.(strategyNames{j}).normal.VaR.alpha_1.pi*100,'%5.2f');
    array{j,3} = num2str(PassiveRiskManagement.(strategyNames{j}).normal.VaR.alpha_1.z,'%5.2f');
    array{j,4} = num2str(PassiveRiskManagement.(strategyNames{j}).t7.VaR.alpha_1.pi*100,'%5.2f');
    array{j,5} = num2str(PassiveRiskManagement.(strategyNames{j}).t7.VaR.alpha_1.z,'%5.2f');
    
    array{j,6} = num2str(PassiveRiskManagement.(strategyNames{j}).normal.VaR.alpha_5.pi*100,'%5.2f');
    array{j,7} = num2str(PassiveRiskManagement.(strategyNames{j}).normal.VaR.alpha_5.z,'%5.2f');
    array{j,8} = num2str(PassiveRiskManagement.(strategyNames{j}).t7.VaR.alpha_5.pi*100,'%5.2f');
    array{j,9} = num2str(PassiveRiskManagement.(strategyNames{j}).t7.VaR.alpha_5.z,'%5.2f');
end
   
for j = 1:size(array,1)
    genericString = array{j,1};
    for k = 2:size(array,2)
            genericString = [genericString, ' & ', array{j,k}]; %#ok<AGROW>
    end
    %             genericString = replace_underscores(genericString);

    fprintf(fid, [genericString, '\\\\ \n']);
end

fprintf(fid, '\\hline \\hline \n');
fprintf(fid, '\\end{tabular} \n');
fprintf(fid, '\\end{center} \n');
fprintf(fid, '\\end{%s} \n',fontSize);
fprintf(fid, '\\end{table} \n');
fclose(fid);







