function marm_tables_passiveRiskManagement_singleUnivariate(baseDirectory,PassiveRiskManagement,distributions,fontSize,alphas)

parameterDescriptions.EQMA          = '($n_0$)';
parameterDescriptions.EWMA          = '($n_0,\\lambda_0$)';
parameterDescriptions.GARCH         = '($p,q$)';
parameterDescriptions.GJR           = '($p,q$)';
parameterDescriptions.TGARCH        = '($p,q$)';

modelTypes = {'EQMA','EWMA','GARCH','GJR','TGARCH'};

[Models, modelNames] = listOfUnivariateModels;

for jAlpha = 1:length(alphas)

    fileName = ['passiveRiskManagement.singleModels.univariate.alpha-',alphas{jAlpha},'.tex'];
    caption = ['VaR Diagnostic Tests for Equally Weighted Portfolio Using Individual Univariate Models ($\\alpha = ', alphas{jAlpha}, '$\\%%)'];

    fid = fopen([baseDirectory,'\tex\tables\',fileName],'w');
    fprintf(fid, '\\begin{table}[h!] \n');
    fprintf(fid, '\\begin{%s} \n',fontSize);
    fprintf(fid, ['\\caption{', caption, '} \n']);
    fprintf(fid, ['\\label{T:', fileName(1:end-4), '} \n']);
    fprintf(fid, '\\begin{center} \n');
    fprintf(fid, '\\begin{tabular}{lrrrr|lrrrr} \n');
    fprintf(fid, '\\\\ \n');
    fprintf(fid, '\\hline \\hline \n');
    fprintf(fid, ['Model type & \\multicolumn{2}{c}{normal} &  \\multicolumn{2}{c}{t7} & ', ...
        ' Model type & \\multicolumn{2}{c}{normal} & \\multicolumn{2}{c}{t7} \\\\ \n']);
    fprintf(fid, ['& $\\hat{\\pi}$ & $z_{\\hat{\\pi}}$ & $\\hat{\\pi}$ & \\multicolumn{1}{r}{$z_{\\hat{\\pi}}$} & ', ...
        '& $\\hat{\\pi}$ & $z_{\\hat{\\pi}}$ & $\\hat{\\pi}$ & $z_{\\hat{\\pi}}$ \\\\ \n']);
    fprintf(fid, '\\hline \n');

    array = cell(length(modelNames),5);

    for j = 1:length(modelNames)
        array{j,1} = modelNames{j};
        array{j,2} = PassiveRiskManagement.(modelNames{j}).normal.VaR.(['alpha_',num2str(alphas{jAlpha})]).pi*100;
        array{j,3} = PassiveRiskManagement.(modelNames{j}).normal.VaR.(['alpha_',num2str(alphas{jAlpha})]).z;
        array{j,4} = PassiveRiskManagement.(modelNames{j}).t7.VaR.(['alpha_',num2str(alphas{jAlpha})]).pi*100;
        array{j,5} = PassiveRiskManagement.(modelNames{j}).t7.VaR.(['alpha_',num2str(alphas{jAlpha})]).z;
    end

    outputArray = cell(20,10);
    rowCounter = 2;
    columnCounter = 0;
    for j = 1:length(modelTypes)
        if strcmp(modelTypes{j},'GARCH')
            rowCounter = 2;
            columnCounter = 5;
        end
        outputArray{rowCounter,columnCounter+1} = modelTypes{j};
        rowCounter = rowCounter + 1;
        outputArray{rowCounter,columnCounter+1} = parameterDescriptions.(modelTypes{j});
        rowCounter = rowCounter + 1;
        for k = 1:length(modelNames)
            if strcmp(Models.(modelNames{k}).type,modelTypes{j})

                if iscell(Models.(modelNames{k}).fixedParameters)
                    modelParameters = Models.(modelNames{k}).fixedParameters{1};
                else
                    modelParameters = Models.(modelNames{k}).fixedParameters;
                end
                if  strcmp(modelTypes{j},'EWMA')
                    modelParameters = modelParameters(1:2);
                end

                modelParametersString = num2str(modelParameters(1));
                for l = 2:length(modelParameters)
                    modelParametersString = [modelParametersString,',',num2str(modelParameters(l))]; %#ok<AGROW>
                end
                outputArray{rowCounter,columnCounter+1} = ['(',modelParametersString,')'];
                loc = strmatch(modelNames{k},array(:,1));
                outputArray{rowCounter,columnCounter+2} = num2str(array{loc,2},'%5.2f');
                outputArray{rowCounter,columnCounter+3} = num2str(array{loc,3},'%5.2f');
                outputArray{rowCounter,columnCounter+4} = num2str(array{loc,4},'%5.2f');
                outputArray{rowCounter,columnCounter+5} = num2str(array{loc,5},'%5.2f');

                rowCounter = rowCounter + 1;
            end
        end
        rowCounter = rowCounter + 1;
    end

    for j = 1:size(outputArray,1)
        genericString = outputArray{j,1};
        for k = 2:size(outputArray,2)
            genericString = [genericString, ' & ', outputArray{j,k}]; %#ok<AGROW>
        end
        %             genericString = replace_underscores(genericString);

        fprintf(fid, [genericString, '\\\\ \n']);
    end

    fprintf(fid, '\\hline \\hline \n');
    fprintf(fid, '\\end{tabular} \n');
    fprintf(fid, '\\end{center} \n');
    fprintf(fid, '\\end{%s} \n',fontSize);
    fprintf(fid, '\\end{table} \n');
    fclose(fid);

end


% ---------------------------------- combined table for alpha = 1 and 5 % --------------------------------------

fileName = 'passiveRiskManagement.singleModels.univariate.tex';
caption = 'VaR Diagnostic Tests for Equally Weighted Portfolio Return Using Individual Univariate Models';

fid = fopen([baseDirectory,'\tex\tables\',fileName],'w');
fprintf(fid, '\\begin{table}[h!] \n');
fprintf(fid, '\\begin{%s} \n',fontSize);
fprintf(fid, ['\\caption{', caption, '} \n']);
fprintf(fid, ['\\label{T:', fileName(1:end-4), '} \n']);
fprintf(fid, '\\begin{center} \n');
fprintf(fid, '\\begin{tabular}{lrrrr|lrrrr} \n');


for jAlpha = 1:length(alphas)

    fprintf(fid, '\\multicolumn{10}{c}{} \\\\ \n');
    if jAlpha == 1
        fprintf(fid, '\\multicolumn{10}{c}{$\\alpha = 1\\%% $} \\\\ \n');
    else
        fprintf(fid, '\\multicolumn{10}{c}{$\\alpha = 5\\%% $} \\\\ \n');
    end

    fprintf(fid, '\\multicolumn{10}{c}{} \\\\ \n');

    fprintf(fid, '\\hline \\hline \n');
    fprintf(fid, ['Model type & \\multicolumn{2}{c}{normal} &  \\multicolumn{2}{c}{t7} & ', ...
        ' Model type & \\multicolumn{2}{c}{normal} & \\multicolumn{2}{c}{t7} \\\\ \n']);
    fprintf(fid, ['& $\\hat{\\pi}$ & $z_{\\hat{\\pi}}$ & $\\hat{\\pi}$ & \\multicolumn{1}{r}{$z_{\\hat{\\pi}}$} & ', ...
        '& $\\hat{\\pi}$ & $z_{\\hat{\\pi}}$ & $\\hat{\\pi}$ & $z_{\\hat{\\pi}}$ \\\\ \n']);
    fprintf(fid, '\\hline \n');

    array = cell(length(modelNames),5);

    for j = 1:length(modelNames)
        array{j,1} = modelNames{j};
        array{j,2} = PassiveRiskManagement.(modelNames{j}).normal.VaR.(['alpha_',num2str(alphas{jAlpha})]).pi*100;
        array{j,3} = PassiveRiskManagement.(modelNames{j}).normal.VaR.(['alpha_',num2str(alphas{jAlpha})]).z;
        array{j,4} = PassiveRiskManagement.(modelNames{j}).t7.VaR.(['alpha_',num2str(alphas{jAlpha})]).pi*100;
        array{j,5} = PassiveRiskManagement.(modelNames{j}).t7.VaR.(['alpha_',num2str(alphas{jAlpha})]).z;
    end

    outputArray = cell(20,10);
    rowCounter = 2;
    columnCounter = 0;
    for j = 1:length(modelTypes)
        if strcmp(modelTypes{j},'GARCH')
            rowCounter = 2;
            columnCounter = 5;
        end
        outputArray{rowCounter,columnCounter+1} = modelTypes{j};
        rowCounter = rowCounter + 1;
        outputArray{rowCounter,columnCounter+1} = parameterDescriptions.(modelTypes{j});
        rowCounter = rowCounter + 1;
        for k = 1:length(modelNames)
            if strcmp(Models.(modelNames{k}).type,modelTypes{j})

                if iscell(Models.(modelNames{k}).fixedParameters)
                    modelParameters = Models.(modelNames{k}).fixedParameters{1};
                else
                    modelParameters = Models.(modelNames{k}).fixedParameters;
                end
                if  strcmp(modelTypes{j},'EWMA')
                    modelParameters = modelParameters(1:2);
                end

                modelParametersString = num2str(modelParameters(1));
                for l = 2:length(modelParameters)
                    modelParametersString = [modelParametersString,',',num2str(modelParameters(l))]; %#ok<AGROW>
                end
                outputArray{rowCounter,columnCounter+1} = ['(',modelParametersString,')'];
                loc = strmatch(modelNames{k},array(:,1));
                outputArray{rowCounter,columnCounter+2} = num2str(array{loc,2},'%5.2f');
                outputArray{rowCounter,columnCounter+3} = num2str(array{loc,3},'%5.2f');
                outputArray{rowCounter,columnCounter+4} = num2str(array{loc,4},'%5.2f');
                outputArray{rowCounter,columnCounter+5} = num2str(array{loc,5},'%5.2f');

                rowCounter = rowCounter + 1;
            end
        end
        rowCounter = rowCounter + 1;
    end

    for j = 1:size(outputArray,1)
        genericString = outputArray{j,1};
        for k = 2:size(outputArray,2)
            genericString = [genericString, ' & ', outputArray{j,k}]; %#ok<AGROW>
        end
        %             genericString = replace_underscores(genericString);

        fprintf(fid, [genericString, '\\\\ \n']);
    end

    fprintf(fid, '\\hline \\hline \n');

end

fprintf(fid, '\\end{tabular} \n');
fprintf(fid, '\\end{center} \n');
fprintf(fid, '\\end{%s} \n',fontSize);
fprintf(fid, '\\end{table} \n');
fclose(fid);








