function marm_tables_passiveRiskManagement_singleUnivariate_presentation(baseDirectory,PassiveRiskManagement,distributions,fontSize,alphas)

parameterDescriptions.EQMA          = '($n_0$)';
parameterDescriptions.EWMA          = '($n_0,\\lambda_0$)';
parameterDescriptions.GARCH         = '($p,q$)';
parameterDescriptions.GJR           = '($p,q$)';
parameterDescriptions.TGARCH        = '($p,q$)';

modelTypes = {'EQMA','EWMA','GARCH','GJR','TGARCH'};

[Models, modelNames] = listOfUnivariateModels;

groups{1} = {'EQMA','EWMA'};
groups{2} = {'GARCH','GJR','TGARCH'};


for hGroup = 1:length(groups)

    fileName = ['passiveRiskManagement.singleModels.univariate.presentation.',num2str(hGroup),'.tex'];
%     caption = ['VaR Diagnostic Tests for Equally Weighted Portfolio Using Individual Univariate Models ($\\alpha = ', alphas{jAlpha}, '$\\%%)'];

    fid = fopen([baseDirectory,'\tex\tables\',fileName],'w');
%     fprintf(fid, '\\begin{table}[h!] \n');
    fprintf(fid, '\\begin{%s} \n',fontSize);
%     fprintf(fid, ['\\caption{', caption, '} \n']);
%     fprintf(fid, ['\\label{T:', fileName(1:end-4), '} \n']);
    fprintf(fid, '\\begin{center} \n');
    fprintf(fid, '\\begin{tabular}{lrrrr|rrrr} \n');
    fprintf(fid, '\\\\ \n');
    fprintf(fid, '\\hline \\hline \n');
    fprintf(fid, ' & \\multicolumn{4}{c}{$\\alpha = 1\\%%$} & \\multicolumn{4}{c}{$\\alpha = 5\\%%$} \\\\ \n');
    fprintf(fid, ['Strategy type & \\multicolumn{2}{c}{normal} &  \\multicolumn{2}{c}{t7} & ', ...
        ' \\multicolumn{2}{c}{normal} & \\multicolumn{2}{c}{t7} \\\\ \n']);
    fprintf(fid, ['& $\\hat{\\pi}$ & $z_{\\hat{\\pi}}$ & $\\hat{\\pi}$ & \\multicolumn{1}{r}{$z_{\\hat{\\pi}}$} & ', ...
        ' $\\hat{\\pi}$ & $z_{\\hat{\\pi}}$ & $\\hat{\\pi}$ & $z_{\\hat{\\pi}}$ \\\\ \n']);
    fprintf(fid, '\\hline \n');

    array = cell(length(modelNames),9);

    for j = 1:length(modelNames)
        array{j,1} = modelNames{j};
        array{j,2} = PassiveRiskManagement.(modelNames{j}).normal.VaR.alpha_1.pi*100;
        array{j,3} = PassiveRiskManagement.(modelNames{j}).normal.VaR.alpha_1.z;
        array{j,4} = PassiveRiskManagement.(modelNames{j}).t7.VaR.alpha_1.pi*100;
        array{j,5} = PassiveRiskManagement.(modelNames{j}).t7.VaR.alpha_1.z;

        array{j,6} = PassiveRiskManagement.(modelNames{j}).normal.VaR.alpha_5.pi*100;
        array{j,7} = PassiveRiskManagement.(modelNames{j}).normal.VaR.alpha_5.z;
        array{j,8} = PassiveRiskManagement.(modelNames{j}).t7.VaR.alpha_5.pi*100;
        array{j,9} = PassiveRiskManagement.(modelNames{j}).t7.VaR.alpha_5.z;
    end

    outputArray = cell(2,9);
    rowCounter = 2;
    columnCounter = 0;
    for j = 1:length(modelTypes)
        if ismember(modelTypes{j},groups{hGroup})
            outputArray{rowCounter,columnCounter+1} = modelTypes{j};
            rowCounter = rowCounter + 1;
            outputArray{rowCounter,columnCounter+1} = parameterDescriptions.(modelTypes{j});
            rowCounter = rowCounter + 1;
            for k = 1:length(modelNames)
                if strcmp(Models.(modelNames{k}).type,modelTypes{j})

                    if iscell(Models.(modelNames{k}).fixedParameters)
                        modelParameters = Models.(modelNames{k}).fixedParameters{1};
                    else
                        modelParameters = Models.(modelNames{k}).fixedParameters;
                    end
                    if  strcmp(modelTypes{j},'EWMA')
                        modelParameters = modelParameters(1:2);
                    end

                    modelParametersString = num2str(modelParameters(1));
                    for l = 2:length(modelParameters)
                        modelParametersString = [modelParametersString,',',num2str(modelParameters(l))]; %#ok<AGROW>
                    end
                    outputArray{rowCounter,columnCounter+1} = ['(',modelParametersString,')'];
                    loc = strmatch(modelNames{k},array(:,1));
                    outputArray{rowCounter,columnCounter+2} = num2str(array{loc,2},'%5.2f');
                    outputArray{rowCounter,columnCounter+3} = num2str(array{loc,3},'%5.2f');
                    outputArray{rowCounter,columnCounter+4} = num2str(array{loc,4},'%5.2f');
                    outputArray{rowCounter,columnCounter+5} = num2str(array{loc,5},'%5.2f');
                    
                    outputArray{rowCounter,columnCounter+6} = num2str(array{loc,6},'%5.2f');
                    outputArray{rowCounter,columnCounter+7} = num2str(array{loc,7},'%5.2f');
                    outputArray{rowCounter,columnCounter+8} = num2str(array{loc,8},'%5.2f');
                    outputArray{rowCounter,columnCounter+9} = num2str(array{loc,9},'%5.2f');

                    rowCounter = rowCounter + 1;
                end
            end
            rowCounter = rowCounter + 1;
        end
    end

    for j = 1:size(outputArray,1)
        genericString = outputArray{j,1};
        for k = 2:size(outputArray,2)
            genericString = [genericString, ' & ', outputArray{j,k}]; %#ok<AGROW>
        end
        %             genericString = replace_underscores(genericString);

        fprintf(fid, [genericString, '\\\\ \n']);
    end

    fprintf(fid, '\\hline \\hline \n');
    fprintf(fid, '\\end{tabular} \n');
    fprintf(fid, '\\end{center} \n');
    fprintf(fid, '\\end{%s} \n',fontSize);
%     fprintf(fid, '\\end{table} \n');
    fclose(fid);

end

