function marm_tables_passiveRiskManagement_single_presentation(baseDirectory,PassiveRiskManagement,distributions,fontSize,alphas)

parameterDescriptions.EQMA          = '($n_0$)';
parameterDescriptions.EWMA          = '($n_0,\\lambda_0,\\nu_0$)';
parameterDescriptions.MMA           = '($n_0,\\nu_0$)';
parameterDescriptions.GEWMA         = '($p,q,\\nu_0$)';
parameterDescriptions.DCC           = '($p,q$)';
parameterDescriptions.ADCC          = '($p,q$)';
parameterDescriptions.CCC           = '($p,q$)';
parameterDescriptions.OGARCH        = '($p,q$)';
parameterDescriptions.factorGARCH   = '($p,q$)';
parameterDescriptions.factorGARCH   = '($p,q$)';
parameterDescriptions.TDCC          = '($p,q$)';

Models = listOfModels;

modelTypes = {'EQMA','EWMA','MMA','GEWMA','OGARCH','CCC','DCC','ADCC','TDCC'};

modelNames = fieldnames(Models);

groups{1} = {'EQMA','EWMA'};
groups{2} = {'MMA','GEWMA','OGARCH'};
groups{3} = {'CCC','DCC','ADCC','TDCC'};

for jAlpha = 1:length(alphas)

    for hGroup = 1:length(groups)

        fileName = ['passiveRiskManagement.singleModels.presentation.',num2str(hGroup),'.tex'];
        caption = ['VaR Diagnostic Tests for Equally Weighted Portfolio Return Using Individual Multivariate Models ($\\alpha = ', alphas{jAlpha}, '$\\%%)'];

        fid = fopen([baseDirectory,'\tex\tables\',fileName],'w');
        %         fprintf(fid, '\\begin{table}[h!] \n');
        fprintf(fid, '\\begin{%s} \n',fontSize);
        %         fprintf(fid, ['\\caption{', caption, '} \n']);
        %         fprintf(fid, ['\\label{T:', fileName(1:end-4), '} \n']);
        fprintf(fid, '\\begin{center} \n');
       fprintf(fid, '\\begin{tabular}{lrrrr|rrrr} \n');
fprintf(fid, '\\\\ \n');
fprintf(fid, '\\hline \\hline \n');
fprintf(fid, ' & \\multicolumn{4}{c}{$\\alpha = 1\\%%$} & \\multicolumn{4}{c}{$\\alpha = 5\\%%$} \\\\ \n');
fprintf(fid, ['Model type & \\multicolumn{2}{c}{normal} &  \\multicolumn{2}{c}{t7} & ', ...
    ' \\multicolumn{2}{c}{normal} & \\multicolumn{2}{c}{t7} \\\\ \n']);
fprintf(fid, ['& $\\hat{\\pi}$ & $z_{\\hat{\\pi}}$ & $\\hat{\\pi}$ & \\multicolumn{1}{r}{$z_{\\hat{\\pi}}$} & ', ...
    ' $\\hat{\\pi}$ & $z_{\\hat{\\pi}}$ & $\\hat{\\pi}$ & $z_{\\hat{\\pi}}$ \\\\ \n']);
fprintf(fid, '\\hline \n');

        array = cell(length(modelNames),10);

        for j = 1:length(modelNames)
            array{j,1} = modelNames{j};
            array{j,2} = PassiveRiskManagement.singleModel.(modelNames{j}).normal.VaR.alpha_1.pi*100;
            array{j,3} = PassiveRiskManagement.singleModel.(modelNames{j}).normal.VaR.alpha_1.z;
            if strcmp(modelNames{j},'TDCC')
                array{j,4} = PassiveRiskManagement.singleModel.(modelNames{j}).endogenous.VaR.alpha_1.pi*100;
                array{j,5} = PassiveRiskManagement.singleModel.(modelNames{j}).endogenous.VaR.alpha_1.z;
            else
                array{j,4} = PassiveRiskManagement.singleModel.(modelNames{j}).t7.VaR.alpha_1.pi*100;
                array{j,5} = PassiveRiskManagement.singleModel.(modelNames{j}).t7.VaR.alpha_1.z;
            end
            
            array{j,6} = modelNames{j};
            array{j,7} = PassiveRiskManagement.singleModel.(modelNames{j}).normal.VaR.alpha_5.pi*100;
            array{j,8} = PassiveRiskManagement.singleModel.(modelNames{j}).normal.VaR.alpha_5.z;
            if strcmp(modelNames{j},'TDCC')
                array{j,9} = PassiveRiskManagement.singleModel.(modelNames{j}).endogenous.VaR.alpha_5.pi*100;
                array{j,10} = PassiveRiskManagement.singleModel.(modelNames{j}).endogenous.VaR.alpha_5.z;
            else
                array{j,9} = PassiveRiskManagement.singleModel.(modelNames{j}).t7.VaR.alpha_5.pi*100;
                array{j,10} = PassiveRiskManagement.singleModel.(modelNames{j}).t7.VaR.alpha_5.z;
            end
            
        end

        outputArray = cell(2,9);
        rowCounter = 2;
        columnCounter = 0;
        for j = 1:length(modelTypes)
            if ismember(modelTypes{j},groups{hGroup})
                %             if strcmp(modelTypes{j},'OGARCH')
                %                 rowCounter = 2;
                %                 columnCounter = 7;
                %             end
                if strcmp(modelTypes{j},'factorGARCH')
                    outputArray{rowCounter,columnCounter+1} = 'factor GARCH';
                else
                    outputArray{rowCounter,columnCounter+1} = modelTypes{j};
                end

                rowCounter = rowCounter + 1;
                outputArray{rowCounter,columnCounter+1} = parameterDescriptions.(modelTypes{j});
                rowCounter = rowCounter + 1;
                for k = 1:length(modelNames)
                    if strcmp(Models.(modelNames{k}).type,modelTypes{j})
                        %                     if strcmp(modelNames{k},'GEWMA_250_1_1_97')
                        %                         rowCounter = 2;
                        %                         columnCounter = 5;
                        %                     end
                        if iscell(Models.(modelNames{k}).fixedParameters)
                            modelParameters = Models.(modelNames{k}).fixedParameters{1};
                        else
                            modelParameters = Models.(modelNames{k}).fixedParameters;
                        end
                        if  strcmp(modelTypes{j},'GEWMA')  % || strcmp(modelTypes{j},'EWMA')
                            modelParameters = modelParameters(2:end);
                        elseif strcmp(modelTypes{j},'TDCC')
                            modelParameters = modelParameters(2:3);
                        end

                        modelParametersString = num2str(modelParameters(1));
                        for l = 2:length(modelParameters)
                            modelParametersString = [modelParametersString,',',num2str(modelParameters(l))]; %#ok<AGROW>
                        end
                        outputArray{rowCounter,columnCounter+1} = ['(',modelParametersString,')'];
                        loc = strmatch(modelNames{k},array(:,1));
                        outputArray{rowCounter,columnCounter+2} = num2str(array{loc,2},'%5.2f');
                        outputArray{rowCounter,columnCounter+3} = num2str(array{loc,3},'%5.2f');
                        outputArray{rowCounter,columnCounter+4} = num2str(array{loc,4},'%5.2f');
                        outputArray{rowCounter,columnCounter+5} = num2str(array{loc,5},'%5.2f');
                        
                        outputArray{rowCounter,columnCounter+6} = num2str(array{loc,7},'%5.2f');
                        outputArray{rowCounter,columnCounter+7} = num2str(array{loc,8},'%5.2f');
                        outputArray{rowCounter,columnCounter+8} = num2str(array{loc,9},'%5.2f');
                        outputArray{rowCounter,columnCounter+9} = num2str(array{loc,10},'%5.2f');

                        rowCounter = rowCounter + 1;
                    end
                end
                rowCounter = rowCounter + 1;
            end
        end

        for j = 1:size(outputArray,1)
            genericString = outputArray{j,1};
            for k = 2:size(outputArray,2)
                if strcmp(outputArray{j,k},'factor GARCH')
                    genericString = [genericString, ' & \\multicolumn{2}{l}{', outputArray{j,k}]; %#ok<AGROW>
                elseif strcmp(outputArray{j,k-1},'factor GARCH')
                    genericString = [genericString, '} ']; %#ok<AGROW>
                else
                    genericString = [genericString, ' & ', outputArray{j,k}]; %#ok<AGROW>
                end
            end
            %             genericString = replace_underscores(genericString);

            fprintf(fid, [genericString, '\\\\ \n']);
        end

        fprintf(fid, '\\hline \\hline \n');
        fprintf(fid, '\\end{tabular} \n');
        fprintf(fid, '\\end{center} \n');
        fprintf(fid, '\\end{%s} \n',fontSize);
        %         fprintf(fid, '\\end{table} \n');
        fclose(fid);

    end

end






