function marm_tables_ranks_multivariate(baseDirectory,Ranks,distributions,fontSize)

parameterDescriptions.EQMA          = '($n_0$)';
parameterDescriptions.EWMA          = '($n_0,\\lambda_0,\\nu_0$)';
parameterDescriptions.MMA           = '($n_0,\\nu_0$)';
parameterDescriptions.GEWMA         = '($p,q,\\nu_0$)';
parameterDescriptions.DCC           = '($p,q$)';
parameterDescriptions.ADCC          = '($p,q$)';
parameterDescriptions.CCC           = '($p,q$)';
parameterDescriptions.OGARCH        = '($p,q$)';
parameterDescriptions.factorGARCH   = '($p,q$)';
parameterDescriptions.factorGARCH   = '($p,q$)';
parameterDescriptions.TDCC          = '($p,q$)';

Models = listOfModels;

modelTypes = {'EQMA','EWMA','MMA','GEWMA','OGARCH','CCC','DCC','ADCC','TDCC'};

modelNames = fieldnames(Models);

criteria = {'AIC','BIC'};
for iDistribution = 1:length(distributions)
    for jCriterion = 1:2
        fileName = ['ranks.multivariate.',distributions{iDistribution},'.',criteria{jCriterion},'.tex'];
        caption = ['Selection Frequencies for Multivariate Models (', distributions{iDistribution}, ', ',criteria{jCriterion} ,')'];

        fid = fopen([baseDirectory,'\tex\tables\',fileName],'w');
        fprintf(fid, '\\begin{table}[htbp] \n');
        fprintf(fid, '\\begin{%s} \n',fontSize);
        fprintf(fid, ['\\caption{', caption, '} \n']);
        fprintf(fid, ['\\label{T:', fileName(1:end-4), '} \n']);
        fprintf(fid, '\\begin{center} \n');
        fprintf(fid, '\\begin{tabular}{lrrrrr|lrrrrr} \n');
        fprintf(fid, '\\\\ \n');
        fprintf(fid, '\\hline \\hline \n');
        fprintf(fid, ' & \\multicolumn{5}{l}{selected in strategy:} &  & \\multicolumn{5}{l}{selected in strategy:} \\\\ \n');
        fprintf(fid, 'Model type & Best & Top 10\\%% & 25\\%% & 50\\%% & 75\\%% & Model type & Best & Top 10\\%% & 25\\%% & 50\\%% & 75\\%% \\\\ \n');
        fprintf(fid, '\\hline \n');

        array = cell(length(modelNames),6);

        for k = 1:length(modelNames)
            array{k,1} = modelNames{k};
            array{k,2} = num2str(Ranks.(modelNames{k}).(distributions{iDistribution}).(criteria{jCriterion}).top,'%1.2f');
            array{k,3} = num2str(Ranks.(modelNames{k}).(distributions{iDistribution}).(criteria{jCriterion}).top10,'%1.2f');
            array{k,4} = num2str(Ranks.(modelNames{k}).(distributions{iDistribution}).(criteria{jCriterion}).top25,'%1.2f');
            array{k,5} = num2str(Ranks.(modelNames{k}).(distributions{iDistribution}).(criteria{jCriterion}).top50,'%1.2f');
            array{k,6} = num2str(Ranks.(modelNames{k}).(distributions{iDistribution}).(criteria{jCriterion}).top75,'%1.2f');
        end

        outputArray = cell(40,12);
        rowCounter = 2;
        columnCounter = 0;
        for j = 1:length(modelTypes)
            if strcmp(modelTypes{j},'factorGARCH')
                outputArray{rowCounter,columnCounter+1} = 'factor GARCH';
            else
                outputArray{rowCounter,columnCounter+1} = modelTypes{j};
            end

            rowCounter = rowCounter + 1;
            outputArray{rowCounter,columnCounter+1} = parameterDescriptions.(modelTypes{j});
            rowCounter = rowCounter + 1;
            for k = 1:length(modelNames)
                if strcmp(Models.(modelNames{k}).type,modelTypes{j})
                    if strcmp(modelNames{k},'GEWMA_250_1_1_97')
                        rowCounter = 2;
                        columnCounter = 6;
                    end
                    if iscell(Models.(modelNames{k}).fixedParameters)
                        modelParameters = Models.(modelNames{k}).fixedParameters{1};
                    else
                        modelParameters = Models.(modelNames{k}).fixedParameters;
                    end
                    if  strcmp(modelTypes{j},'GEWMA')  % || strcmp(modelTypes{j},'EWMA')
                        modelParameters = modelParameters(2:end);
                    elseif strcmp(modelTypes{j},'TDCC')
                        modelParameters = modelParameters(2:3);
                    end

                    modelParametersString = num2str(modelParameters(1));
                    for l = 2:length(modelParameters)
                        modelParametersString = [modelParametersString,',',num2str(modelParameters(l))]; %#ok<AGROW>
                    end
                    outputArray{rowCounter,columnCounter+1} = ['(',modelParametersString,')'];
                    loc = strmatch(modelNames{k},array(:,1));
                    for m = 1:5
                        outputArray{rowCounter,columnCounter+m+1} = array{loc,m+1};
                    end
                    rowCounter = rowCounter + 1;
                end
            end
            rowCounter = rowCounter + 1;
        end

        for j = 1:size(outputArray,1)
            genericString = outputArray{j,1};
            for k = 2:size(outputArray,2)
                if strcmp(outputArray{j,k},'factor GARCH')
                    genericString = [genericString, ' & \\multicolumn{2}{l}{', outputArray{j,k}]; %#ok<AGROW>
                elseif strcmp(outputArray{j,k-1},'factor GARCH')
                    genericString = [genericString, '} ']; %#ok<AGROW>
                else
                    genericString = [genericString, ' & ', outputArray{j,k}]; %#ok<AGROW>
                end
            end
            %             genericString = replace_underscores(genericString);

            fprintf(fid, [genericString, '\\\\ \n']);
        end

        fprintf(fid, '\\hline \\hline \n');
        fprintf(fid, '\\end{tabular} \n');
        fprintf(fid, '\\end{center} \n');
        fprintf(fid, '\\end{%s} \n',fontSize);
        fprintf(fid, '\\end{table} \n');
        fclose(fid);
    end
end






