function marm_tables_summary_stats(baseDirectory, data, UnivariateGARCHs, fontSize)

if ~exist('data','var'), load([baseDirectory,'data.mat']), end

[T,N] = size(data.returns);

statistics.mean = nanmean(data.returns)*100;
statistics.std  = nanstd(data.returns);
statistics.skew = skewness(data.returns);
statistics.kurt = kurtosis(data.returns);
for j = 1:N
    statistics.GARCH.GARCH(1,j) = UnivariateGARCHs{j}(1);
    statistics.GARCH.ARCH(1,j)  = UnivariateGARCHs{j}(2);
    statistics.GARCH.DOF(1,j)   = UnivariateGARCHs{j}(3);
end

tableName = 'summary-stats';
caption = 'Summary Statistics and Univariate GARCH Models';

fid = fopen([baseDirectory,'\tex\tables\',tableName,'.tex'],'w');
fprintf(fid, '\\begin{table}[htbp] \n');
fprintf(fid, '\\begin{%s} \n',fontSize);
fprintf(fid, ['\\caption{', caption, '} \n']);
fprintf(fid, ['\\label{T:', tableName, '} \n']);
fprintf(fid, '\\begin{center} \n');
fprintf(fid, '\\begin{tabular}{lrrrrrrr} \n');
fprintf(fid, '\\\\ \n');
fprintf(fid, '\\multicolumn{8}{r}{(in per cent)} \\\\ \n');
fprintf(fid, '\\hline \\hline \n');
fprintf(fid, 'Asset & Mean             & St.Dev. & Skewness & Kurtosis & \\multicolumn{3}{c}{$t$-GARCH(1,1)} \\\\ \n');
fprintf(fid, '      & ($\\times$ 100)  &         &          &          & $\\hat{\\alpha}_j$ & $\\hat{\\beta}_j$ & $\\hat{\\nu}_j$ \\\\ \n');
fprintf(fid, '\\hline \n');
% --------------------------------------------------------------------------------------------------------
% currencies
% --------------------------------------------------------------------------------------------------------
fprintf(fid, '\\multicolumn{8}{l}{\\textbf{Currencies}} \\\\ \n');
indices = 1:6;
for j = 1:length(indices)
    output = [statistics.mean(indices(j)), statistics.std(indices(j)), statistics.skew(indices(j)), ...
        statistics.kurt(indices(j)), statistics.GARCH.ARCH(indices(j)), ...
        statistics.GARCH.GARCH(indices(j)), statistics.GARCH.DOF(indices(j))];
    fprintf(fid, ['\\ \\ ', data.variableNamesShort{indices(j)}, ...
        '  & %1.3f & %1.3f & %1.3f & %1.3f & %1.3f & %1.3f & %1.3f \\\\ \n'], output);
end
output = mean([statistics.mean(indices)', statistics.std(indices)', statistics.skew(indices)', ...
    statistics.kurt(indices)', statistics.GARCH.ARCH(indices)', ...
    statistics.GARCH.GARCH(indices)', statistics.GARCH.DOF(indices)'],1);
fprintf(fid, '\\hline \n');
fprintf(fid, ['\\ \\ \\emph{mean} ', ...
    '  & \\emph{%1.3f} & \\emph{%1.3f} & \\emph{%1.3f} & \\emph{%1.3f} & \\emph{%1.3f} & \\emph{%1.3f} & \\emph{%1.3f} \\\\ \n'], output);
fprintf(fid, '\\hline \n');
% equities
% --------------------------------------------------------------------------------------------------------
fprintf(fid, '\\multicolumn{8}{l}{\\textbf{Equities}} \\\\ \n');
indices = 7:10;
for j = 1:length(indices)
    output = [statistics.mean(indices(j)), statistics.std(indices(j)), statistics.skew(indices(j)), ...
        statistics.kurt(indices(j)), statistics.GARCH.ARCH(indices(j)), ...
        statistics.GARCH.GARCH(indices(j)), statistics.GARCH.DOF(indices(j))];
    fprintf(fid, ['\\ \\ ', data.variableNamesShort{indices(j)}, ...
        '  & %1.3f & %1.3f & %1.3f & %1.3f & %1.3f & %1.3f & %1.3f \\\\ \n'], output);
end
output = mean([statistics.mean(indices)', statistics.std(indices)', statistics.skew(indices)', ...
    statistics.kurt(indices)', statistics.GARCH.ARCH(indices)', ...
    statistics.GARCH.GARCH(indices)', statistics.GARCH.DOF(indices)'],1);
fprintf(fid, '\\hline \n');
fprintf(fid, ['\\ \\ \\emph{mean} ', ...
    '  & \\emph{%1.3f} & \\emph{%1.3f} & \\emph{%1.3f} & \\emph{%1.3f} & \\emph{%1.3f} & \\emph{%1.3f} & \\emph{%1.3f} \\\\ \n'], output);
fprintf(fid, '\\hline \n');
% --------------------------------------------------------------------------------------------------------
% bonds
% --------------------------------------------------------------------------------------------------------
fprintf(fid, '\\multicolumn{8}{l}{\\textbf{Bonds}} \\\\ \n');
indices = 11:14;
for j = 1:length(indices)
    output = [statistics.mean(indices(j)), statistics.std(indices(j)), statistics.skew(indices(j)), ...
        statistics.kurt(indices(j)), statistics.GARCH.ARCH(indices(j)), ...
        statistics.GARCH.GARCH(indices(j)), statistics.GARCH.DOF(indices(j))];
    fprintf(fid, ['\\ \\ ', data.variableNamesShort{indices(j)}, ...
        '  & %1.3f & %1.3f & %1.3f & %1.3f & %1.3f & %1.3f & %1.3f \\\\ \n'], output);
end
output = mean([statistics.mean(indices)', statistics.std(indices)', statistics.skew(indices)', ...
    statistics.kurt(indices)', statistics.GARCH.ARCH(indices)', ...
    statistics.GARCH.GARCH(indices)', statistics.GARCH.DOF(indices)'],1);
fprintf(fid, '\\hline \n');
fprintf(fid, ['\\ \\ \\emph{mean} ', ...
    '  & \\emph{%1.3f} & \\emph{%1.3f} & \\emph{%1.3f} & \\emph{%1.3f} & \\emph{%1.3f} & \\emph{%1.3f} & \\emph{%1.3f} \\\\ \n'], output);
fprintf(fid, '\\hline \n');
% --------------------------------------------------------------------------------------------------------
% commodities
% --------------------------------------------------------------------------------------------------------
fprintf(fid, '\\multicolumn{8}{l}{\\textbf{Commodities}} \\\\ \n');
indices = 15:18;
for j = 1:length(indices)
    output = [statistics.mean(indices(j)), statistics.std(indices(j)), statistics.skew(indices(j)), ...
        statistics.kurt(indices(j)), statistics.GARCH.ARCH(indices(j)), ...
        statistics.GARCH.GARCH(indices(j)), statistics.GARCH.DOF(indices(j))];
    fprintf(fid, ['\\ \\ ', data.variableNamesShort{indices(j)}, ...
        '  & %1.3f & %1.3f & %1.3f & %1.3f & %1.3f & %1.3f & %1.3f \\\\ \n'], output);
end
output = mean([statistics.mean(indices)', statistics.std(indices)', statistics.skew(indices)', ...
    statistics.kurt(indices)', statistics.GARCH.ARCH(indices)', ...
    statistics.GARCH.GARCH(indices)', statistics.GARCH.DOF(indices)'],1);
fprintf(fid, '\\hline \n');
fprintf(fid, ['\\ \\ \\emph{mean} ', ...
    '  & \\emph{%1.3f} & \\emph{%1.3f} & \\emph{%1.3f} & \\emph{%1.3f} & \\emph{%1.3f} & \\emph{%1.3f} & \\emph{%1.3f} \\\\ \n'], output);

fprintf(fid, '\\hline \\hline \n');

%% all assets
output = mean([statistics.mean', statistics.std', statistics.skew', ...
    statistics.kurt', statistics.GARCH.ARCH', ...
    statistics.GARCH.GARCH', statistics.GARCH.DOF'],1);
fprintf(fid, ['\\ \\ \\emph{mean(all assets)} ', ...
    '  & \\emph{%1.3f} & \\emph{%1.3f} & \\emph{%1.3f} & \\emph{%1.3f} & \\emph{%1.3f} & \\emph{%1.3f} & \\emph{%1.3f} \\\\ \n'], output);
fprintf(fid, '\\hline \\hline \n');

%%
fprintf(fid, '\\end{tabular} \n');
fprintf(fid, '\\end{center} \n');
fprintf(fid, '\\end{%s} \n',fontSize);
fprintf(fid, '\\end{table} \n');

fclose(fid);


%
%
%
% \begin{tabular}{llllllllll}
% \multicolumn{10}{c}{\textbf{Table 3: VaR Diagnostic Tests }} \\
% \multicolumn{10}{c}{Recursive estimation with expanding window for an
% equal-weighted portfolio} \\
% \multicolumn{10}{c}{} \\
% \multicolumn{10}{l}{\textit{Panel A}: $\,\,\,\,\,\,\,\,\,\,\,\,\,\,\,\,\,\,%
% \,\,\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
% \ \ \ \ \alpha =1\%$} \\ \hline\hline
% &  &  &  &  &  &  &  &  &  \\
% &  & \multicolumn{2}{c}{Normal} &  & \multicolumn{2}{c}{Student (8)} &  &
% \multicolumn{2}{l}{Student (6)} \\
% &  & \multicolumn{1}{c}{$\hat{\pi}$} & \multicolumn{1}{c}{$z_{\hat{\pi}}$} &
% \multicolumn{1}{c}{} & \multicolumn{1}{c}{$\hat{\pi}$} & \multicolumn{1}{c}{$%
% z_{\hat{\pi}}$} & \multicolumn{1}{c}{} & \multicolumn{1}{c}{$\hat{\pi}$} & $%
% z_{\hat{\pi}}$ \\
% \textit{Modelling Strategies} &  &  &  &  &  &  &  &  &  \\
% \textbf{Best} &  &  &  &  &  &  &  &  &  \\
% AIC &  & 1.972 & 2.200 &  & 0.592 & -0.924 &  & 0.394 & -1.370 \\
