function passiveRiskManagement = do_passiveRiskManagementAverageModel(OneStepPredictors, SampleLikelihoods, strategy, ...
    data, windowSize, distributions, estimationOutput)

returns = data.returns;
mu      = data.cond_m_ar1;
nAssets = size(mu,2);

modelNames = fieldnames(SampleLikelihoods);
nModels = length(modelNames);
if strcmp(strategy.nModels,'all')
    strategy.nModels = nModels;
end

[T,N] = size(returns);
omegaStar = ones(N,1)/N; % portfolio with equal weights

x = (-5:0.01:5)';
for j = 1:length(distributions)
    passiveRiskManagement.(distributions{j}).return = nan(T,1);
    passiveRiskManagement.(distributions{j}).return_1 = nan(T,1);
    passiveRiskManagement.(distributions{j}).return_5 = nan(T,1);
    if strcmpi(distributions{j},'normal')
        DoF.(distributions{j}) = inf;
        distributionTemplate.(distributions{j}) = [x, normcdf(x)];
    elseif strcmpi(distributions{j}(1),'t')
        DoF.(distributions{j}) = str2double(distributions{j}(2:end));
        distributionTemplate.(distributions{j}) = [x, tcdf(x,DoF.(distributions{j}))];
    end
end

figureTitle = strategy.name;
figureTitle(figureTitle=='_') = '-';
h = waitbar(0, figureTitle);
for t = windowSize+2:T
    if ~mod(t,10)
        waitbar((t-windowSize)/(T-windowSize), h);
        drawnow
    end

    for j = 1:length(distributions)
        allCriteria = nan(nModels,1);
        for k = 1:nModels
            if strcmp(modelNames{k}(1:4),'TGAR') || strcmp(modelNames{k},'TDCC')
                allCriteria(k) = SampleLikelihoods.(modelNames{k}).endogenous.(strategy.criterion)(t);
            else
                allCriteria(k) = SampleLikelihoods.(modelNames{k}).(distributions{j}).(strategy.criterion)(t);
            end
        end
        [sortedCriteria, indexes] = sort(allCriteria,'descend');
        selectedModels = indexes(1:strategy.nModels);
        switch strategy.weighting
            case 'equal'
                weights = ones(strategy.nModels,1)/strategy.nModels;
            case {'AIC','BIC'}
                Delta = nan(strategy.nModels,1);
                for k = 1:strategy.nModels
                    Delta(k) = sortedCriteria(k)-sortedCriteria(1);
                end
                weights = exp(Delta)/sum(exp(Delta));
        end
        Sigma_t = nan(nAssets,nAssets,strategy.nModels);
        mu_t = nan(nAssets,strategy.nModels);
        for k = 1:strategy.nModels
            Sigma_t(:,:,k) = OneStepPredictors.(modelNames{selectedModels(k)}).covariance(:,:,t);
            mu_t(:,k) = mu(t,:);
        end

        passiveRiskManagement.(distributions{j}).return(t) = returns(t,:)*omegaStar;
        passiveRiskManagement.(distributions{j}).return_1(t) = ...
            get_leftTailAverageModel(omegaStar, Sigma_t, mu_t, 0.01, DoF.(distributions{j}), weights);
        passiveRiskManagement.(distributions{j}).return_5(t) = ...
            get_leftTailAverageModel(omegaStar, Sigma_t, mu_t, 0.05, DoF.(distributions{j}), weights);
    end

end
close(h);

for j = 1:length(distributions)
    passiveRiskManagement.(distributions{j}).cumulativeReturn = nan(T,1);
    jReturn = passiveRiskManagement.(distributions{j}).return;
    jVaR_1 = passiveRiskManagement.(distributions{j}).return_1;
    jVaR_5 = passiveRiskManagement.(distributions{j}).return_5;
    passiveRiskManagement.(distributions{j}).cumulativeReturn(~isnan(jReturn)) = cumsum(jReturn(~isnan(jReturn)));
    passiveRiskManagement.(distributions{j}).avReturn = nanmean(jReturn);
    passiveRiskManagement.(distributions{j}).std = nanstd(jReturn);
    passiveRiskManagement.(distributions{j}).IR = nanmean(jReturn) / nanstd(jReturn) * sqrt(250);
    passiveRiskManagement.(distributions{j}).VaR.alpha_1.nViolations = sum(jReturn < jVaR_1);
    passiveRiskManagement.(distributions{j}).VaR.alpha_5.nViolations = sum(jReturn < jVaR_5);
    T1 = sum(~isnan(jReturn));
    pi_1 = sum(jReturn < jVaR_1) / T1;
    pi_5 = sum(jReturn < jVaR_5) / T1;
    z_1 = sqrt(T1)*(pi_1-0.01)/sqrt(0.01*(1-0.01));
    z_5 = sqrt(T1)*(pi_5-0.05)/sqrt(0.05*(1-0.05));
    passiveRiskManagement.(distributions{j}).VaR.alpha_1.pi = pi_1;
    passiveRiskManagement.(distributions{j}).VaR.alpha_5.pi = pi_5;
    passiveRiskManagement.(distributions{j}).VaR.alpha_1.z = z_1;
    passiveRiskManagement.(distributions{j}).VaR.alpha_5.z = z_5;
    passiveRiskManagement.(distributions{j}).VaR.alpha_1.pi_pVal = 1-bino_cdf(T1*pi_1,T1,0.01);
    passiveRiskManagement.(distributions{j}).VaR.alpha_5.pi_pVal = 1-bino_cdf(T1*pi_5,T1,0.05);
    passiveRiskManagement.(distributions{j}).VaR.alpha_1.z_pVal = 1-normcdf(z_1);
    passiveRiskManagement.(distributions{j}).VaR.alpha_5.z_pVal = 1-normcdf(z_5);
end

