function passiveRiskManagement = do_passiveRiskManagementSingleModel(OneStepPredictors, modelName, data, windowSize, ...
    distributions, estimationOutput)

returns = data.returns;
mu      = data.cond_m_ar1;

[T,N] = size(returns);
omegaStar = ones(N,1)/N; % portfolio with equal weights

if strcmp(modelName, 'TDCC') || strcmp(modelName(1:4), 'TGAR')
    distributions = [distributions, 'endogenous'];
    updateIndexes = estimationOutput.updateIndexes;
end

for j = 1:length(distributions)
    passiveRiskManagement.(distributions{j}).return = nan(T,1);
    passiveRiskManagement.(distributions{j}).return_1 = nan(T,1);
    passiveRiskManagement.(distributions{j}).return_5 = nan(T,1);
    if strcmpi(distributions{j},'normal')
        DoF.(distributions{j}) = inf;
        cAlphaTilde.alpha_1.(distributions{j}) = norminv(0.01)*(-1);
        cAlphaTilde.alpha_5.(distributions{j}) = norminv(0.05)*(-1);
    elseif strcmpi(distributions{j}(1),'t')
        DoF.(distributions{j}) = str2double(distributions{j}(2:end));
        cAlphaTilde.alpha_1.(distributions{j}) = tinv(0.01,DoF.(distributions{j}))*(-1)...
            *sqrt((DoF.(distributions{j})-2)/DoF.(distributions{j}));
        cAlphaTilde.alpha_5.(distributions{j}) = tinv(0.05,DoF.(distributions{j}))*(-1)...
            *sqrt((DoF.(distributions{j})-2)/DoF.(distributions{j}));
    end
end

figureTitle = modelName;
figureTitle(figureTitle=='_') = '-';
h = waitbar(0, figureTitle);
for t = windowSize+2:T
    if ~mod(t,100)
        waitbar((t-windowSize)/(T-windowSize), h);
        drawnow
    end
    % -----------------------------------------------------------------------------------------
    % we need to get the DoF parameter for the TDCC model:
    if strcmp(modelName, 'TDCC') || strcmp(modelName(1:4), 'TGAR')
        if strcmp(estimationOutput.estimateParameters,'yes') && ismember(t-1,updateIndexes)
            estimatedParameters = estimationOutput.estimatedParameters{find(updateIndexes == t-1)};
            endogenous_DoF = estimatedParameters(end);
            DoF.endogenous = endogenous_DoF;
            cAlphaTilde.alpha_1.endogenous = tinv(0.01,DoF.endogenous)*(-1)...
                *sqrt((DoF.endogenous-2)/DoF.endogenous);
            cAlphaTilde.alpha_5.endogenous = tinv(0.05,DoF.endogenous)*(-1)...
                *sqrt((DoF.endogenous-2)/DoF.endogenous);
        end
    end
    % -----------------------------------------------------------------------------------------
    mu_t = mu(t,:)';
    expectedReturn = mu_t'*omegaStar;
    if size(OneStepPredictors.covariance,2) == 1
        % univariate case:
        variance = OneStepPredictors.covariance(t);
    else
        % multivariate case
        Sigma_t = OneStepPredictors.covariance(:,:,t);
        if ~isreal(Sigma_t)
            error('Sigma is complex')
        end
        %     Sigma_t = diag(diag(Sigma_t));
        variance = omegaStar'*Sigma_t*omegaStar;
    end

    for j = 1:length(distributions)
        passiveRiskManagement.(distributions{j}).return(t) = returns(t,:)*omegaStar;
        passiveRiskManagement.(distributions{j}).return_1(t) = ...
            get_leftTail(variance, expectedReturn, 0.01, DoF.(distributions{j}), cAlphaTilde.alpha_1.(distributions{j}));
        passiveRiskManagement.(distributions{j}).return_5(t) = ...
            get_leftTail(variance, expectedReturn, 0.05, DoF.(distributions{j}), cAlphaTilde.alpha_5.(distributions{j}));
    end
end
close(h);

for j = 1:length(distributions)
    passiveRiskManagement.(distributions{j}).cumulativeReturn = nan(T,1);
    jReturn = passiveRiskManagement.(distributions{j}).return;
    jVaR_1 = passiveRiskManagement.(distributions{j}).return_1;
    jVaR_5 = passiveRiskManagement.(distributions{j}).return_5;
    passiveRiskManagement.(distributions{j}).cumulativeReturn(~isnan(jReturn)) = cumsum(jReturn(~isnan(jReturn)));
    passiveRiskManagement.(distributions{j}).avReturn = nanmean(jReturn);
    passiveRiskManagement.(distributions{j}).std = nanstd(jReturn);
    passiveRiskManagement.(distributions{j}).IR = nanmean(jReturn) / nanstd(jReturn) * sqrt(250);
    passiveRiskManagement.(distributions{j}).VaR.alpha_1.nViolations = sum(jReturn < jVaR_1);
    passiveRiskManagement.(distributions{j}).VaR.alpha_5.nViolations = sum(jReturn < jVaR_5);
    T1 = sum(~isnan(jReturn));
    pi_1 = sum(jReturn < jVaR_1) / T1;
    pi_5 = sum(jReturn < jVaR_5) / T1;
    z_1 = sqrt(T1)*(pi_1-0.01)/sqrt(0.01*(1-0.01));
    z_5 = sqrt(T1)*(pi_5-0.05)/sqrt(0.05*(1-0.05));
    passiveRiskManagement.(distributions{j}).VaR.alpha_1.pi = pi_1;
    passiveRiskManagement.(distributions{j}).VaR.alpha_5.pi = pi_5;
    passiveRiskManagement.(distributions{j}).VaR.alpha_1.z = z_1;
    passiveRiskManagement.(distributions{j}).VaR.alpha_5.z = z_5;
    passiveRiskManagement.(distributions{j}).VaR.alpha_1.pi_pVal = 1-bino_cdf(T1*pi_1,T1,0.01);
    passiveRiskManagement.(distributions{j}).VaR.alpha_5.pi_pVal = 1-bino_cdf(T1*pi_5,T1,0.05);
    passiveRiskManagement.(distributions{j}).VaR.alpha_1.z_pVal = 1-normcdf(z_1);
    passiveRiskManagement.(distributions{j}).VaR.alpha_5.z_pVal = 1-normcdf(z_5);
end

