function leftTail = get_leftTailAverageModel(omega, Sigma, mu, alpha, DoF, weights, distribution)

if ~exist('distribution','var'), distribution = []; end

nModels = size(mu,2);
numerator = nan(nModels,1);
denominator = nan(nModels,1);
for j = 1:nModels
    numerator(j) = -omega'*mu(:,j);
    denominator(j) = sqrt(omega'*Sigma(:,:,j)*omega);
end

tail_low = 0;
tail_high = get_leftTail(omega'*Sigma(:,:,1)*omega, omega'*mu(:,1), alpha, DoF);

VaR_low = compute_excessVaR(numerator, denominator, -tail_low, weights, alpha, DoF, distribution);
VaR_high = compute_excessVaR(numerator, denominator, -tail_high, weights, alpha, DoF, distribution);

% figure(1)
epsilon = 10^(-7);
notYetConverged = 1;
nIterations = 0;
while notYetConverged
    tail_sec = tail_high - VaR_high*(tail_high - tail_low)/(VaR_high - VaR_low);
    VaR_sec = compute_excessVaR(numerator, denominator, -tail_sec, weights, alpha, DoF, distribution);
    if sign(VaR_sec) <= 0
        delta_tail = abs(tail_low-tail_sec);
        tail_low = tail_sec;
        VaR_low = VaR_sec;
    elseif sign(VaR_sec) > 0
        delta_tail = abs(tail_high-tail_sec);
        tail_high = tail_sec;
        VaR_high = VaR_sec;
    end
    notYetConverged = delta_tail > epsilon && abs(VaR_high-VaR_low) > epsilon;
    %             disp(VaR_sec)
    %             plot([tail_sec,tail_sec],[0,VaR_sec]), hold on
    nIterations = nIterations + 1;
end
leftTail = tail_sec;

function excessVaR = compute_excessVaR(numerator, denominator, maximumLoss, weights, alpha, DoF, distribution)

if exist('distribution','var')
    if isempty(distribution), clear distribution, end
end

numerator = numerator - maximumLoss;
standardizedReturn = numerator ./ denominator;
if isinf(DoF)
        cdf = normcdf(standardizedReturn);
else
    if exist('distribution','var')
        cdf = interp1(distribution(:,1),distribution(:,2),standardizedReturn/sqrt((DoF-2)/DoF));
    else
        cdf = tcdf(standardizedReturn/sqrt((DoF-2)/DoF),DoF);
    end
end
VaR = weights(:)'*cdf;
excessVaR = VaR - alpha;

%figure(1), plot(distribution(:,1),distribution(:,2)), hold on, scatter(standardizedReturn/sqrt((DoF-2)/DoF),cdf)
