function  [ranks, averageBayesianWeight] = get_ranks(SampleLikelihoods, modelNames, distributions, windowSize, data)

[T,N] = size(data.returns);
nModels = length(modelNames);

criteria = {'AIC','BIC'};
tRanks = struct;
BayesianWeights = struct;
for j = 1:length(distributions)
    for k = 1:length(criteria)
        tRanks.(distributions{j}).(criteria{k}) = nan(T,nModels);
        BayesianWeights.(distributions{j}).(criteria{k}) = nan(T,nModels);
    end
end

figureTitle = 'computing rank';
h = waitbar(0, figureTitle);
for t = windowSize+2:T
    if ~mod(t,10)
        waitbar((t-windowSize)/(T-windowSize), h);
        drawnow
    end
    for j = 1:length(distributions)
        for k = 1:length(criteria)
            allCriteria = nan(nModels,1);
            for l = 1:nModels
                if strcmp(modelNames{l},'TDCC')
                    allCriteria(l) = SampleLikelihoods.(modelNames{l}).endogenous.(criteria{k})(t);
                else
                    allCriteria(l) = SampleLikelihoods.(modelNames{l}).(distributions{j}).(criteria{k})(t);
                end
            end
            [sortedCriteria, indexes] = sort(allCriteria,'descend');
            [sortedIndexes, ranks_t] = sort(indexes);
            tRanks.(distributions{j}).(criteria{k})(t,:) = ranks_t';
               Delta = nan(nModels,1);
                for l = 1:nModels
                    Delta(l) = sortedCriteria(l)-sortedCriteria(1);
                end
                BayesianWeights.(distributions{j}).(criteria{k})(t,:) = (exp(Delta)/sum(exp(Delta)))';
        end
    end
end
close(h);

for j = 1:nModels
    for k = 1:length(criteria)
        for l = 1:length(distributions)
            ranks.(modelNames{j}).(distributions{l}).(criteria{k}).top = ...
                nansum(tRanks.(distributions{l}).(criteria{k})(:,j) == 1) / (T-windowSize-1);
            ranks.(modelNames{j}).(distributions{l}).(criteria{k}).top10 = ...
                nansum(tRanks.(distributions{l}).(criteria{k})(:,j) <= ceil(10*nModels/100)) / (T-windowSize-1);
            ranks.(modelNames{j}).(distributions{l}).(criteria{k}).top25 = ...
                nansum(tRanks.(distributions{l}).(criteria{k})(:,j) <= ceil(25*nModels/100)) / (T-windowSize-1);
            ranks.(modelNames{j}).(distributions{l}).(criteria{k}).top50 = ...
                nansum(tRanks.(distributions{l}).(criteria{k})(:,j) <= ceil(50*nModels/100)) / (T-windowSize-1);
            ranks.(modelNames{j}).(distributions{l}).(criteria{k}).top75 = ...
                nansum(tRanks.(distributions{l}).(criteria{k})(:,j) <= ceil(50*nModels/100)) / (T-windowSize-1);
        end
    end
end
for j = 1:length(distributions)
    for k = 1:length(criteria)
        averageBayesianWeight.(distributions{j}).(criteria{k}) = nanmean(BayesianWeights.(distributions{j}).(criteria{k}),1);
    end
end




