function Sigma = evaluate_EWMA(series, n_0, lambda_0, nu_0)

%  ---------------------------------------------------------------------
%  PURPOSE: computes a covariance estimate using the exponentially-
%           weighted moving average (EWMA)
%  ---------------------------------------------------------------------
%  USAGE: Sigma = evaluate_EWMA(series, n_0, lambda_0, nu_0)
%  where: n_0       = window size
%         lambda_0  = decay factor of variances
%         nu_0      = decay factor of co-variances
% ---------------------------------------------------------------------
%  RETURNS: the covariance matrix
% ---------------------------------------------------------------------
%  written by Christoph Schleicher (christoph@iam.ubc.ca)
% ---------------------------------------------------------------------

[T,N] = size(series);
Sigma = nan(N,N,T+1);

Sigma_lambda = riskMetrics(series(1:n_0,:), n_0, lambda_0);
Sigma_nu     = riskMetrics(series(1:n_0,:), n_0, nu_0);
for t = n_0:T
    if t > n_0
        Sigma_lambda = lambda_0 * Sigma_lambda + (1-lambda_0) / (1-lambda_0^n_0) * series(t,:)'*series(t,:) ...
            - (1-lambda_0)/(1-lambda_0^n_0)*lambda_0^(n_0-1) * series(t-n_0,:)'*series(t-n_0,:);
        Sigma_nu = nu_0 * Sigma_nu + (1-nu_0) / (1-nu_0^n_0) * series(t,:)'*series(t,:) ...
            - (1-nu_0)/(1-nu_0^n_0)*nu_0^(n_0-1) * series(t-n_0,:)'*series(t-n_0,:);
    end
    D = diag(sqrt(diag(Sigma_lambda)));
    R = Sigma_nu ./ (sqrt(diag(Sigma_nu))*sqrt(diag(Sigma_nu))');
    
    Sigma(:,:,t+1) = D*R*D;
end