function [LLF, h] = GJRLikelihood(parameters, data, p, q, errorType)

% author: Christoph Schleicher (christoph@iam.ubc.ca)

T = length(data);
m = max(p, q);
isPositive = data > 0;
isNegative = data < 0;

% -------------------------------------------------------------------------------------
% use filter to recursively compute the conditional covariance h
% -------------------------------------------------------------------------------------
yPositive = [nan; filter(parameters(2:1+p),1,isPositive(1:end-1).*data(1:end-1).^2)];
yNegative = [nan; filter(parameters(2+p:1+2*p),1,isNegative(1:end-1).*data(1:end-1).^2)];
intermediate = yPositive + yNegative + parameters(1);
intermediate(1:m) = data(1)^2;
h = filter(1, [1;-parameters(2+2*p:end)]', intermediate);

% -------------------------------------------------------------------------------------
% this does the same as the following code (but about 60 times faster)
% -------------------------------------------------------------------------------------
% h = zeros(size(data));
% h(1:m) = data(1)^2;
% isPositive = data > 0;
% isNegative = data < 0;
% for t = (m + 1):T
%     h(t) = parameters(1:1+2*p+q)' * ...
%         [1; ...
%         isPositive(t-(1:p)).*data(t-(1:p)).^2; ...
%         isNegative(t-(1:p)).*data(t-(1:p)).^2; ...
%         h(t-(1:q))];
% end
% -------------------------------------------------------------------------------------

Tau = T-m;
t = (m + 1):T;
switch lower(errorType)
    case 'normal'
        LLF  =  sum(log(h(t))) + sum((data(t).^2)./h(t));
        LLF  =  0.5 * (LLF  +  Tau*log(2*pi));
    case 'studentst'
        nu = parameters(end);
        LLF = Tau*gammaln(0.5*(nu+1)) - Tau*gammaln(nu/2) - Tau/2*log(pi*(nu-2));
        LLF = LLF - 0.5*sum(log(h(t))) - ((nu+1)/2)*sum(log(1 + (data(t).^2)./(h(t)*(nu-2)) ));
        LLF = -LLF;
    case 'ged'
        nu = parameters(end);
        Beta = (2^(-2/nu) * gamma(1/nu)/gamma(3/nu))^(0.5);
        LLF = (Tau * log(nu)) - (Tau*log(Beta)) - (Tau*gammaln(1/nu)) - Tau*(1+1/nu)*log(2);
        LLF = LLF - 0.5 * sum(log(h(t))) - 0.5 * sum((abs(data(t)./(sqrt(h(t))*Beta))).^nu);
        LLF = -LLF;
end

if ~isreal(h)
    disp('imag')
    LLF = 10^10;
end

if min(h) < 0
    disp('negative volatilities')
    LLF = 10^10;
end

