function Sigma = evaluate_MMA(series, n_0, nu_0)

%  ---------------------------------------------------------------------
%  PURPOSE: computes a covariance estimate using the mixed moving average
%  (MMA)
%  ---------------------------------------------------------------------
%  USAGE: Sigma = evaluate_MMA(series, n_0, nu_0)
%  where: n_0       = window size
%         nu_0      = decay factor of co-variances
% ---------------------------------------------------------------------
%  RETURNS: the covariance matrix
% ---------------------------------------------------------------------
%  written by Christoph Schleicher (christoph@iam.ubc.ca)
% ---------------------------------------------------------------------

[T,N] = size(series);
Sigma = nan(N,N,T+1);

Sigma_EQMA = evaluate_EQMA(series, n_0);
Sigma_riskMetrics = evaluate_EWMA(series, n_0, nu_0, nu_0);

for t = 1:T+1
    D = diag(sqrt(diag(Sigma_EQMA(:,:,t))));
    R = Sigma_riskMetrics(:,:,t) ./ (sqrt(diag(Sigma_riskMetrics(:,:,t)))*sqrt(diag(Sigma_riskMetrics(:,:,t)))');
    Sigma(:,:,t) = D*R*D;
end