function Sigma = riskMetrics(series, n_0, lambda_0)

%  ---------------------------------------------------------------------
%  PURPOSE: computes a covariance estimate using the exponentially-
%           weighted moving average
%  ---------------------------------------------------------------------
%  USAGE: Sigma = riskMetrics(series, n_0, lambda_0)
%  where: n_0       = window size
%         lambda_0  = decay factor of variances
% ---------------------------------------------------------------------
%  RETURNS: the covariance matrix
% ---------------------------------------------------------------------
%  written by Christoph Schleicher (christoph@iam.ubc.ca)
% ---------------------------------------------------------------------

N = size(series,2);
series = series(end-n_0+1:end,:);
Sigma = zeros(N,N);
for t = 1:n_0
    Sigma = Sigma + (1-lambda_0)/(1-lambda_0^n_0)*lambda_0^(n_0-t)* ...
        series(t,:)'*series(t,:);
end