function  estimatedParameters = estimate_volatilityModel(modelDescription, tReturns, startingValues)

verbose = 1;
nTries = 5;

if ~exist('startingValues','var'), startingValues = []; end

switch modelDescription.type

    case 'GEWMA'
        N = size(tReturns,2);
        estimatedParameters = cell(N,1);
        p        = modelDescription.fixedParameters(2);
        q        = modelDescription.fixedParameters(3);
        options = set_options(p, q);
        for j = 1:N
            if ~isempty(startingValues)
                startingValues_j = startingValues{j};
            else
                startingValues_j = [];
            end
            try
                estimatedParameters{j} = ...
                    estimate_GARCH(tReturns(:,j), p, q, 'Normal', nTries, verbose, options, startingValues_j);
            catch
                keyboard
            end
        end

    case 'CCC'
        p        = modelDescription.fixedParameters(1);
        q        = modelDescription.fixedParameters(2);
        options = set_options(p, q);
        if ~isempty(startingValues)
            estimatedParameters = estimate_CCC(tReturns, p, q, nTries, verbose, options, startingValues);
        else
            estimatedParameters = estimate_CCC(tReturns, p, q, nTries, verbose, options);
        end

    case 'OGARCH'
        p        = modelDescription.fixedParameters(1);
        q        = modelDescription.fixedParameters(2);
        options = set_options(p, q);
        if ~isempty(startingValues)
            estimatedParameters = estimate_OGARCH(tReturns, p, q, 'Normal', nTries, verbose, options, startingValues);
        else
            estimatedParameters = estimate_OGARCH(tReturns, p, q, 'Normal', nTries, verbose, options);
        end

    case 'HRS'
        p        = modelDescription.fixedParameters(1);
        q        = modelDescription.fixedParameters(2);
        estimatedParameters = estimate_HRS(tReturns, 1, 1, p, q, nTries, verbose);

    case 'DCC'
        p        = modelDescription.fixedParameters(1);
        q        = modelDescription.fixedParameters(2);
        if ~isempty(startingValues)
            estimatedParameters = estimate_DCC(tReturns, 1, 1, p, q, nTries, verbose, startingValues);
        else
            estimatedParameters = estimate_DCC(tReturns, 1, 1, p, q, nTries, verbose);
        end

    case 'ADCC'
        p        = modelDescription.fixedParameters(1);
        q        = modelDescription.fixedParameters(2);
        if ~isempty(startingValues)
            estimatedParameters = estimate_ADCC(tReturns, 1, 1, p, q, nTries, verbose, startingValues);
        else
            estimatedParameters = estimate_ADCC(tReturns, 1, 1, p, q, nTries, verbose);
        end

    case 'factorGARCH'
        p        = modelDescription.fixedParameters(1);
        q        = modelDescription.fixedParameters(2);
        if ~isempty(startingValues)
            estimatedParameters = estimate_factorGARCH(tReturns, p, q, 'normal', nTries, verbose, startingValues);
        else
            estimatedParameters = estimate_factorGARCH(tReturns, p, q, 'normal', nTries, verbose);
        end

    case {'TDCC'}
        nLags    = modelDescription.fixedParameters{1};
        mode     = modelDescription.fixedParameters{2};
        if ~isempty(startingValues)
            estimatedParameters = estimate_TDCC(tReturns, nLags, mode, startingValues);
        else
            estimatedParameters = estimate_TDCC(tReturns, nLags, mode);
        end

    case {'GARCH','TGARCH'}
        p        = modelDescription.fixedParameters(1);
        q        = modelDescription.fixedParameters(2);
        options = set_options(p, q);
        switch modelDescription.type
            case 'GARCH'
                errors = 'NORMAL';
            case 'TGARCH'
                errors = 'STUDENTST';
        end
        if ~isempty(startingValues)
            estimatedParameters = estimate_GARCH(tReturns, p, q, errors, nTries, verbose, options, startingValues);
        else
            estimatedParameters = estimate_GARCH(tReturns, p, q, errors, nTries, verbose, options);
        end
        
    case 'GJR'
        p        = modelDescription.fixedParameters(1);
        q        = modelDescription.fixedParameters(2);
        options = set_options(p, q);
        if ~isempty(startingValues)
            estimatedParameters = estimate_GJR(tReturns, p, q, 'NORMAL', nTries, verbose, options, startingValues);
        else
            estimatedParameters = estimate_GJR(tReturns, p, q, 'NORMAL', nTries, verbose, options);
        end        

end

% ------------------ set the options for the optimization toolbox ------------------
function options = set_options(p, q)

options = optimset('fmincon');
options = optimset(options, ...
    'Display','off', ...
    'Diagnostics','off', ...
    'MaxFunEvals', 1000*max(p+q+1), ...
    'MaxIter',1000*max(p+q+1), ...
    'LargeScale','off', ...
    'MaxSQPIter',1000);