function Sigma = evaluate_volatilityModel(modelDescription, tReturns, estimatedParameters)

switch modelDescription.type
    case 'EQMA'
        n_0 = modelDescription.fixedParameters(1);
        Sigma = evaluate_EQMA(tReturns, n_0);

    case 'EWMA'
        n_0      = modelDescription.fixedParameters(1);
        lambda_0 = modelDescription.fixedParameters(2);
        nu_0     = modelDescription.fixedParameters(3);
        Sigma = evaluate_EWMA(tReturns, n_0, lambda_0, nu_0);

    case 'MMA'
        n_0  = modelDescription.fixedParameters(1);
        nu_0 = modelDescription.fixedParameters(2);
        Sigma = evaluate_MMA(tReturns, n_0, nu_0);

    case 'GEWMA'
        n_0      = modelDescription.fixedParameters(1);
        p        = modelDescription.fixedParameters(2);
        q        = modelDescription.fixedParameters(3);
        nu_0     = modelDescription.fixedParameters(4);
        Sigma = evaluate_GEWMA(tReturns, n_0, p, q, nu_0, estimatedParameters);

    case 'CCC'
        p        = modelDescription.fixedParameters(1);
        q        = modelDescription.fixedParameters(2);
        Sigma = evaluate_CCC(tReturns, p, q, estimatedParameters);

    case 'OGARCH'
        p        = modelDescription.fixedParameters(1);
        q        = modelDescription.fixedParameters(2);
        Sigma = evaluate_OGARCH(tReturns, p, q, estimatedParameters);

    case 'factorGARCH'
        p        = modelDescription.fixedParameters(1);
        q        = modelDescription.fixedParameters(2);
        Sigma = evaluate_factorGARCH(tReturns, p, q, estimatedParameters);

    case 'DCC'
        p        = modelDescription.fixedParameters(1);
        q        = modelDescription.fixedParameters(2);
        Sigma = evaluate_DCC(tReturns, 1, 1, p, q, estimatedParameters);

    case 'ADCC'
        p        = modelDescription.fixedParameters(1);
        q        = modelDescription.fixedParameters(2);
        Sigma = evaluate_ADCC(tReturns, 1, 1, p, q, estimatedParameters);

    case 'TDCC'
        p       = modelDescription.fixedParameters{1};
        mode    = modelDescription.fixedParameters{2};
        [minusLogLikelihood, H_t] = TDCC_likelihood(estimatedParameters, tReturns, p, mode);
        Sigma = H_t;

    case 'GARCH'
        p        = modelDescription.fixedParameters(1);
        q        = modelDescription.fixedParameters(2);
        Sigma = evaluate_GARCH(tReturns, estimatedParameters, p, q);

    case 'TGARCH'
        p        = modelDescription.fixedParameters(1);
        q        = modelDescription.fixedParameters(2);
        Sigma = evaluate_GARCH(tReturns, estimatedParameters(1:end-1), p, q);

    case 'GJR'
        p        = modelDescription.fixedParameters(1);
        q        = modelDescription.fixedParameters(2);
        Sigma = evaluate_GJR(tReturns, estimatedParameters, p, q);

end
