function [Models, modelNames] = listOfModels(Models)

if ~exist('Models','var'), Models = struct; end

% -----------------------------------------------------------------------------------------------------------
% 1 EQMA(n_0) - Equally Weighted Moving Average
% -----------------------------------------------------------------------------------------------------------

Models.EQMA_250 = struct('type','EQMA','fixedParameters',250,'estimateParameters','no');
Models.EQMA_125 = struct('type','EQMA','fixedParameters',125,'estimateParameters','no');
Models.EQMA_75  = struct('type','EQMA','fixedParameters',75,'estimateParameters','no');
Models.EQMA_50  = struct('type','EQMA','fixedParameters',50,'estimateParameters','no');

% -----------------------------------------------------------------------------------------------------------
% 2 EWMA(n_0) - Exponentially Weighted Moving Average
% -----------------------------------------------------------------------------------------------------------

Models.EWMA_250_95_95 = struct('type','EWMA','fixedParameters',[250, 0.95, 0.95],'estimateParameters','no');
Models.EWMA_250_97_95 = struct('type','EWMA','fixedParameters',[250, 0.97, 0.95],'estimateParameters','no');
Models.EWMA_250_95_97 = struct('type','EWMA','fixedParameters',[250, 0.95, 0.97],'estimateParameters','no');
Models.EWMA_250_97_97 = struct('type','EWMA','fixedParameters',[250, 0.97, 0.97],'estimateParameters','no');

Models.EWMA_125_95_95 = struct('type','EWMA','fixedParameters',[125, 0.95, 0.95],'estimateParameters','no');
Models.EWMA_125_97_95 = struct('type','EWMA','fixedParameters',[125, 0.97, 0.95],'estimateParameters','no');
Models.EWMA_125_95_97 = struct('type','EWMA','fixedParameters',[125, 0.95, 0.97],'estimateParameters','no');
Models.EWMA_125_97_97 = struct('type','EWMA','fixedParameters',[125, 0.97, 0.97],'estimateParameters','no');

Models.EWMA_75_95_95 = struct('type','EWMA','fixedParameters',[75, 0.95, 0.95],'estimateParameters','no');
Models.EWMA_75_97_95 = struct('type','EWMA','fixedParameters',[75, 0.97, 0.95],'estimateParameters','no');
Models.EWMA_75_95_97 = struct('type','EWMA','fixedParameters',[75, 0.95, 0.97],'estimateParameters','no');
Models.EWMA_75_97_97 = struct('type','EWMA','fixedParameters',[75, 0.97, 0.97],'estimateParameters','no');

Models.EWMA_50_95_95 = struct('type','EWMA','fixedParameters',[50, 0.95, 0.95],'estimateParameters','no');
Models.EWMA_50_97_95 = struct('type','EWMA','fixedParameters',[50, 0.97, 0.95],'estimateParameters','no');
Models.EWMA_50_95_97 = struct('type','EWMA','fixedParameters',[50, 0.95, 0.97],'estimateParameters','no');
Models.EWMA_50_97_97 = struct('type','EWMA','fixedParameters',[50, 0.97, 0.97],'estimateParameters','no');

% -----------------------------------------------------------------------------------------------------------
% 3 MMA(n_0, nu_0) - Mixed Moving Average
% -----------------------------------------------------------------------------------------------------------

Models.MMA_250_95 = struct('type','MMA','fixedParameters',[250, 0.95],'estimateParameters','no');
Models.MMA_250_97 = struct('type','MMA','fixedParameters',[250, 0.97],'estimateParameters','no');

Models.MMA_125_95 = struct('type','MMA','fixedParameters',[125, 0.95],'estimateParameters','no');
Models.MMA_125_97 = struct('type','MMA','fixedParameters',[125, 0.97],'estimateParameters','no');

Models.MMA_75_95 = struct('type','MMA','fixedParameters',[75, 0.95],'estimateParameters','no');
Models.MMA_75_97 = struct('type','MMA','fixedParameters',[75, 0.97],'estimateParameters','no');

Models.MMA_50_95 = struct('type','MMA','fixedParameters',[50, 0.95],'estimateParameters','no');
Models.MMA_50_97 = struct('type','MMA','fixedParameters',[50, 0.97],'estimateParameters','no');

% -----------------------------------------------------------------------------------------------------------
% 4 GEWMA(n_0, p, q, nu_0) - Generalized Exponentially-Weighted Moving Average
% -----------------------------------------------------------------------------------------------------------

Models.GEWMA_250_1_1_95 = struct('type','GEWMA','fixedParameters',[250, 1, 1, 0.95],'estimateParameters','yes');
Models.GEWMA_250_1_2_95 = struct('type','GEWMA','fixedParameters',[250, 1, 2, 0.95],'estimateParameters','yes');
Models.GEWMA_250_2_1_95 = struct('type','GEWMA','fixedParameters',[250, 2, 1, 0.95],'estimateParameters','yes');
Models.GEWMA_250_2_2_95 = struct('type','GEWMA','fixedParameters',[250, 2, 2, 0.95],'estimateParameters','yes');

Models.GEWMA_250_1_1_97 = struct('type','GEWMA','fixedParameters',[250, 1, 1, 0.97],'estimateParameters','yes');
Models.GEWMA_250_1_2_97 = struct('type','GEWMA','fixedParameters',[250, 1, 2, 0.97],'estimateParameters','yes');
Models.GEWMA_250_2_1_97 = struct('type','GEWMA','fixedParameters',[250, 2, 1, 0.97],'estimateParameters','yes');
Models.GEWMA_250_2_2_97 = struct('type','GEWMA','fixedParameters',[250, 2, 2, 0.97],'estimateParameters','yes');

% -----------------------------------------------------------------------------------------------------------
% 5 CCC(p, q) - Constant Conditional Correlation
% -----------------------------------------------------------------------------------------------------------

Models.CCC_1_1 = struct('type','CCC','fixedParameters',[1, 1],'estimateParameters','yes');
Models.CCC_1_2 = struct('type','CCC','fixedParameters',[1, 2],'estimateParameters','yes');
Models.CCC_2_1 = struct('type','CCC','fixedParameters',[2, 1],'estimateParameters','yes');
Models.CCC_2_2 = struct('type','CCC','fixedParameters',[2, 2],'estimateParameters','yes');

% -----------------------------------------------------------------------------------------------------------
% 6 OGARCH(p, q) - Orthogonal GARCH
% -----------------------------------------------------------------------------------------------------------

Models.OGARCH_1_1 = struct('type','OGARCH','fixedParameters',[1, 1],'estimateParameters','yes');
Models.OGARCH_1_2 = struct('type','OGARCH','fixedParameters',[1, 2],'estimateParameters','yes');
Models.OGARCH_2_1 = struct('type','OGARCH','fixedParameters',[2, 1],'estimateParameters','yes');
Models.OGARCH_2_2 = struct('type','OGARCH','fixedParameters',[2, 2],'estimateParameters','yes');

% -----------------------------------------------------------------------------------------------------------
% 7 DCC(p, q) - Dynamic Conditional Correlation
% -----------------------------------------------------------------------------------------------------------

Models.DCC_1_1 = struct('type','DCC','fixedParameters',[1, 1],'estimateParameters','yes');
Models.DCC_1_2 = struct('type','DCC','fixedParameters',[1, 2],'estimateParameters','yes');
Models.DCC_2_1 = struct('type','DCC','fixedParameters',[2, 1],'estimateParameters','yes');
Models.DCC_2_2 = struct('type','DCC','fixedParameters',[2, 2],'estimateParameters','yes');

% -----------------------------------------------------------------------------------------------------------
% 8 ADCC(p, q) - Asymmetric Dynamic Conditional Correlation
% -----------------------------------------------------------------------------------------------------------

Models.ADCC_1_1 = struct('type','ADCC','fixedParameters',[1, 1],'estimateParameters','yes');
Models.ADCC_1_2 = struct('type','ADCC','fixedParameters',[1, 2],'estimateParameters','yes');
Models.ADCC_2_1 = struct('type','ADCC','fixedParameters',[2, 1],'estimateParameters','yes');
Models.ADCC_2_2 = struct('type','ADCC','fixedParameters',[2, 2],'estimateParameters','yes');

% -----------------------------------------------------------------------------------------------------------
% 9 TDCC(p, q) - Pesaran and Pesaran's t-DCC (mean-reverting)
% -----------------------------------------------------------------------------------------------------------

Models.TDCC.type = 'TDCC';
Models.TDCC.fixedParameters{1} = [20, 1, 1, 1, 1];
Models.TDCC.fixedParameters{2} = 'mean-reverting';
Models.TDCC.estimateParameters = 'yes';

% -----------------------------------------------------------------------------------------------------------
modelNames = fieldnames(Models);
