function [UnivariateModels, univariateModelNames] = listOfUnivariateModels(UnivariateModels)

if ~exist('UnivariateModels','var'), UnivariateModels = struct; end

% -----------------------------------------------------------------------------------------------------------
% 1.1 EQMA(n_0) - Equally Weighted Moving Average
% -----------------------------------------------------------------------------------------------------------

UnivariateModels.EQMA_250 = struct('type','EQMA','fixedParameters',250,'estimateParameters','no');
UnivariateModels.EQMA_125 = struct('type','EQMA','fixedParameters',125,'estimateParameters','no');
UnivariateModels.EQMA_75  = struct('type','EQMA','fixedParameters',75,'estimateParameters','no');
UnivariateModels.EQMA_50  = struct('type','EQMA','fixedParameters',50,'estimateParameters','no');

% -----------------------------------------------------------------------------------------------------------
% 1.2 EWMA(n_0) - Exponentially Weighted Moving Average
% -----------------------------------------------------------------------------------------------------------

UnivariateModels.EWMA_250_95 = struct('type','EWMA','fixedParameters',[250, 0.95, 0.95],'estimateParameters','no');
UnivariateModels.EWMA_250_97 = struct('type','EWMA','fixedParameters',[250, 0.97, 0.95],'estimateParameters','no');

UnivariateModels.EWMA_125_95 = struct('type','EWMA','fixedParameters',[125, 0.95, 0.95],'estimateParameters','no');
UnivariateModels.EWMA_125_97 = struct('type','EWMA','fixedParameters',[125, 0.97, 0.95],'estimateParameters','no');

UnivariateModels.EWMA_75_95 = struct('type','EWMA','fixedParameters',[75, 0.95, 0.95],'estimateParameters','no');
UnivariateModels.EWMA_75_97 = struct('type','EWMA','fixedParameters',[75, 0.97, 0.95],'estimateParameters','no');

UnivariateModels.EWMA_50_95 = struct('type','EWMA','fixedParameters',[50, 0.95, 0.95],'estimateParameters','no');
UnivariateModels.EWMA_50_97 = struct('type','EWMA','fixedParameters',[50, 0.97, 0.95],'estimateParameters','no');

% -----------------------------------------------------------------------------------------------------------
% 1.3 GARCH(p,q)
% -----------------------------------------------------------------------------------------------------------

UnivariateModels.GARCH_1_1 = struct('type','GARCH','fixedParameters',[1,1],'estimateParameters','yes');
UnivariateModels.GARCH_2_1 = struct('type','GARCH','fixedParameters',[2,1],'estimateParameters','yes');
UnivariateModels.GARCH_1_2 = struct('type','GARCH','fixedParameters',[1,2],'estimateParameters','yes');
UnivariateModels.GARCH_2_2 = struct('type','GARCH','fixedParameters',[2,2],'estimateParameters','yes');

% -----------------------------------------------------------------------------------------------------------
% 1.4 GJR(p,q)
% -----------------------------------------------------------------------------------------------------------

UnivariateModels.GJR_1_1 = struct('type','GJR','fixedParameters',[1,1],'estimateParameters','yes');
UnivariateModels.GJR_2_1 = struct('type','GJR','fixedParameters',[2,1],'estimateParameters','yes');
UnivariateModels.GJR_1_2 = struct('type','GJR','fixedParameters',[1,2],'estimateParameters','yes');
UnivariateModels.GJR_2_2 = struct('type','GJR','fixedParameters',[2,2],'estimateParameters','yes');

% -----------------------------------------------------------------------------------------------------------
% 1.5 TGARCH(p,q)
% -----------------------------------------------------------------------------------------------------------

UnivariateModels.TGARCH_1_1 = struct('type','TGARCH','fixedParameters',[1,1],'estimateParameters','yes');
UnivariateModels.TGARCH_2_1 = struct('type','TGARCH','fixedParameters',[2,1],'estimateParameters','yes');
UnivariateModels.TGARCH_1_2 = struct('type','TGARCH','fixedParameters',[1,2],'estimateParameters','yes');
UnivariateModels.TGARCH_2_2 = struct('type','TGARCH','fixedParameters',[2,2],'estimateParameters','yes');

% -----------------------------------------------------------------------------------------------------------
univariateModelNames = fieldnames(UnivariateModels);
