function output = estimate_univariateModels(modelDescription, returns, windowSize, estimationFrequency, modelName, ...
    portfolioWeights, distributions)

output = modelDescription;

[T,N] = size(returns);

if isequal(portfolioWeights,'equal')
    portfolioWeights = ones(N,1)/N;
end
portfolioReturn = returns*portfolioWeights;

if strcmp(modelName(1:6), 'TGARCH')
    distributions = [distributions, 'endogenous'];
end

output.predictors.covariance = nan(T,1);
for j = 1:length(distributions)
    output.sampleLikelihoods.(distributions{j}).likelihood = nan(T,1);
    output.sampleLikelihoods.(distributions{j}).BIC        = nan(T,1);
    output.sampleLikelihoods.(distributions{j}).AIC        = nan(T,1);
    output.predictors.likelihoods.(distributions{j})       = nan(T,1);
end

updateIndexes = (windowSize+1:estimationFrequency:T);
output.updateIndexes = updateIndexes;
output.estimatedParameters = cell(length(updateIndexes),1);

estimatedParameters = [];
modelName(modelName=='_') = '-';
h = waitbar(0, modelName);
for t = windowSize+1:T
    waitbar((t-windowSize)/(T-windowSize), h)
    drawnow
    tReturn = portfolioReturn(t-windowSize+1:t);
    if strcmp(modelDescription.estimateParameters,'yes') && ismember(t,updateIndexes)
        disp(t)
        estimatedParameters = estimate_volatilityModel(modelDescription, tReturn, estimatedParameters);
        output.estimatedParameters{updateIndexes == t} = estimatedParameters;
    end
    Sigma = evaluate_volatilityModel(modelDescription, tReturn, estimatedParameters);
    Sigma = squeeze(Sigma);

    % --------------------------------------------------------------

    if strcmp(modelName(1:6), 'TGARCH')
        endogenous_DoF = estimatedParameters(end);
    end
    nParameters = get_nParameters(estimatedParameters, modelDescription.type);

    if t < T
        x_InvSigma_x   = portfolioReturn(t-windowSize+1:t+1).^2./Sigma;
        output.predictors.covariance(t+1) = Sigma(windowSize+1);
    else
        x_InvSigma_x   = portfolioReturn(t-windowSize+1:t).^2./Sigma(1:windowSize);
    end
    for j = 1:length(distributions)
        if strcmpi(distributions{j},'normal')
            distributionType = 'normal';
            dof = [];
        end
        if strcmpi(distributions{j}(1),'t')
            distributionType = 'student-t';
            dof = str2num(distributions{j}(2:end));
        elseif strcmpi(distributions{j},'endogenous')
            distributionType = 'student-t';
            dof = endogenous_DoF;
        end
        output.sampleLikelihoods.(distributions{j}).likelihood(t) = ...
            compute_likelihood(portfolioReturn(t-windowSize+1:t),...
            Sigma(1:windowSize),x_InvSigma_x(1:windowSize),distributionType,dof);
        output.sampleLikelihoods.(distributions{j}).AIC(t) = ...
            output.sampleLikelihoods.(distributions{j}).likelihood(t) - nParameters;
        output.sampleLikelihoods.(distributions{j}).BIC(t) = ...
            output.sampleLikelihoods.(distributions{j}).likelihood(t) - 0.5*nParameters*log(windowSize);
        if t < T
            output.predictors.likelihoods.(distributions{j})(t) = ...
                compute_likelihood(portfolioReturn(t+1,:),...
                Sigma(windowSize+1),x_InvSigma_x(windowSize+1),distributionType,dof);
        end
    end

    % --------------------------------------------------------------

end
close(h)


function logLikelihood = compute_likelihood(returns, Sigma, x_invSigma_x, distribution, nu)

[T,N] = size(returns);

tLogLikelihoods = nan(T,1);
switch distribution
    case 'normal'
        tLogLikelihoods = -0.5*N*log(2*pi) - 0.5*log(Sigma) - 0.5*x_invSigma_x;

    case 'student-t'
        tLogLikelihoods = log(gamma(0.5*(N+nu))/gamma(0.5*nu)) - 0.5*N*log(pi) - 0.5*N*log(nu-2) ...
            - 0.5*log(Sigma) - 0.5*(N+nu)*log(1+x_invSigma_x/(nu-2));
end
nMissingObs = sum(isnan(tLogLikelihoods));
logLikelihood = nansum(tLogLikelihoods);
logLikelihood = logLikelihood * T / (T-nMissingObs);
